package jp.veritrans.tercerog.sample.command.card;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;


/**
 * CardAuthorizeCommand : カード決済(与信)サンプル
 */
public class CardAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 与信方法(同時売上実施の有無)
        String withCapture = "false";
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // 支払方法
        String jpo = "10";
        // トークン
        String token = "0a812412-682c-4dad-8a5d-720caf23bca0";
        // カード番号
        // String cardNumber = "4111-1111-1111-1111";
        // カード有効期限
        // String cardExpire = "12/13";
        // セキュリティコード
        // String securityCode = "1234";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        CardAuthorizeRequestDto reqDto = new CardAuthorizeRequestDto();
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // ペイメントオプション(支払方法・回数)の設定
        reqDto.setJpo(jpo);
        // トークンの設定
        reqDto.setToken(token);
        // カード番号の設定
        // reqDto.setCardNumber(cardNumber);
        // カード有効期限の設定
        // reqDto.setCardExpire(cardExpire);
        // セキュリティコード設定
        // reqDto.setSecurityCode(securityCode);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        CardAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (CardAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Card(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);
            Custom.print("JPO", jpo);
            Custom.print("Token", token);
            // Custom.print("Card Number", cardNumber);
            // Custom.print("Card Expired Date", cardExpire);
            // Custom.print("Security Code(CVV2)", securityCode);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Auth Code", resDto.getResAuthCode());
            Custom.print("Reference Number", resDto.getResReturnReferenceNumber());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
