package jp.veritrans.tercerog.sample.command.card;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardReAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;


/**
 * CardReAuthorizeCommand : カード決済(再与信)サンプル
 */
public class CardReAuthorizeCommand {

	/**
	 * コマンドテスト用メインメソッド
	 */
	public static void main(String[] args) {

		//---------------------------------
		// テスト用リクエスト電文項目設定  
		//---------------------------------
	    // 取引ID(自動生成)
	    String orderID = Custom.getOrderID();
	    // 元取引ID(再与信対象)
	    String originalOrderID = "1234567890";
		// 与信方法(同時売上実施の有無)
	    String withCapture = "false";
	    // 支払金額(自動取得)
	    String amount = Custom.getAmount();
	    // 支払方法
	    String jpo = "10";
	    // セキュリティコード
	    String securityCode = "1234";
		
		//---------------------------------
		// リクエスト DTO 設定  
		//---------------------------------
	    CardReAuthorizeRequestDto reqDto = new CardReAuthorizeRequestDto();
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // 元取引ID(再与信対象)の設定
        reqDto.setOriginalOrderId(originalOrderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // ペイメントオプション(支払方法・回数)の設定
        reqDto.setJpo(jpo);
        // セキュリティコード設定
        reqDto.setSecurityCode(securityCode);
		
		//---------------------------------
		// 決済実行と結果表示  
		//---------------------------------
        ITransaction tran = null;
        CardReAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (CardReAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Card(ReAuthorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Original Order ID", originalOrderID);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);
            Custom.print("JPO", jpo);
            Custom.print("Security Code(CVV2)", securityCode);
            
            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Auth Code", resDto.getResAuthCode());
            Custom.print("Reference Number", resDto.getResReturnReferenceNumber());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
	
	}

}
