package jp.veritrans.tercerog.sample.command.carrier;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CarrierAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.CarrierAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * CarrierAuthorizeCommand : キャリア決済(与信)サンプル
 */
public class CarrierAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // キャリア
        String carrier = "au";
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 与信方法(同時売上実施の有無)
        String withCapture = "false";
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // 都度継続区分
        String accountingType = "0";
        // 端末種別
        String terminalKind = "0";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        CarrierAuthorizeRequestDto reqDto = new CarrierAuthorizeRequestDto();
        // キャリア
        reqDto.setServiceOptionType(carrier);
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // 商品番号
        reqDto.setItemId("123456");
        // 都度継続区分
        reqDto.setAccountingType(accountingType);
        // 端末種別
        reqDto.setTerminalKind(terminalKind);
        // 商品タイプ
        reqDto.setItemType("0");
        // OpenId
        reqDto.setOpenId("https://st.connect.auone.jp/net/id/hny_rt_net/cca/s/f4ufhEbtPfqw3Jp4/9kcZhyhOJU1AUct1");

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        CarrierAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (CarrierAuthorizeResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Carrier(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Carrier", carrier);
            Custom.print("Order ID", orderID);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);
            Custom.print("Accounting Type", accountingType);
            Custom.print("TerminalKind", terminalKind);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Response Contents", resDto.getResponseContents());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
