package jp.veritrans.tercerog.sample.command.em;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.EmAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.EmAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * EmAuthorizeCommand : 電子マネー決済(決済申込)サンプル
 */
public class EmAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // [決済方式]
        // サイバーEdy : edy-pc
        // モバイルEdy : edy-mobile
        // モバイルEdyダイレクト : edy-direct
        // モバイルSuicaメール決済 : suica-mobile-mail
        // モバイルSuicaアプリ決済 : suica-mobile-app
        // Suicaインターネット決済メール連携 : suica-pc-mail
        // Suicaインターネット決済アプリ連携 : suica-pc-app
        // WAON モバイルアプリ決済 : waon-mobile
        // WAON PaSoRi決済 : waon-pc
        // nanaco決済 : tcc-redirect
        String serviceOptionType = "suica-mobile-app";
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // 決済期限
        String settlementLimit = Custom.getPaymentLimit("yyyyMMddHHmmss", 10);
        // 取消期限
        String cancelLimit = Custom.getPaymentLimit("yyyyMMddHHmmss", 10);
        // メールアドレス
        String mailAddress = "sample.sample@vt-mdk.co.jp";
        // 画面タイトル
        String screenTitle = "For Mobile Suica";
        // ユーザーID
        String userId = "user001";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        EmAuthorizeRequestDto reqDto = new EmAuthorizeRequestDto();
        // 決済方式の設定
        reqDto.setServiceOptionType(serviceOptionType);
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 決済期限の設定
        if (!"edy-pc".equals(serviceOptionType) //
                && !"edy-direct".equals(serviceOptionType) //
                && !"tcc-redirect".equals(serviceOptionType)) {
            reqDto.setSettlementLimit(settlementLimit);
        }
        // メールアドレスの設定
        if (!"edy-pc".equals(serviceOptionType) //
                && !"edy-direct".equals(serviceOptionType) //
                && !"suica-mobile-app".equals(serviceOptionType) //
                && !"suica-pc-app".equals(serviceOptionType) //
                && !"tcc-redirect".equals(serviceOptionType)) {
            reqDto.setMailAddr(mailAddress);
        }

        if (serviceOptionType.startsWith("suica")) {
            // Suica決済の場合
            reqDto.setScreenTitle(screenTitle);

        } else if ("waon-pc".equals(serviceOptionType)) {
            // WAON PaSoRi決済の場合
            reqDto.setCancelLimit(cancelLimit);

            /* サンプルのためダミーURLを設定 */
            reqDto.setSuccessUrl("http://127.0.0.1/web/PaymentMethodSelect?status=success");
            reqDto.setFailureUrl("http://127.0.0.1/web/PaymentMethodSelect?status=failure");
            reqDto.setCancelUrl("http://127.0.0.1/web/PaymentMethodSelect?status=cancel");

        } else if ("waon-mobile".equals(serviceOptionType)) {
            // WAON モバイルアプリ決済の場合
            reqDto.setCancelLimit(cancelLimit);

        } else if ("tcc-redirect".equals(serviceOptionType)) {
            // nanaco決済の場合
            reqDto.setTransactionKind("02");    // 02:電子マネー固定
            reqDto.setUserId(userId);

            /* サンプルのためダミーURLを設定 */
            reqDto.setCompleteNoticeUrl("http://127.0.0.1/web/em/Complete");
        }

        // ---------------------------------
        // 決済実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        EmAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (EmAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Em(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("ServiceOptionType", serviceOptionType);
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            if (!"edy-pc".equals(serviceOptionType) //
                    && !"edy-direct".equals(serviceOptionType) //
                    && !"tcc-redirect".equals(serviceOptionType)) {
                Custom.print("Settlement Limit", settlementLimit);
            }
            if (!"edy-pc".equals(serviceOptionType) //
                    && !"edy-direct".equals(serviceOptionType) //
                    && !"suica-mobile-app".equals(serviceOptionType) //
                    && !"suica-pc-app".equals(serviceOptionType) //
                    && !"tcc-redirect".equals(serviceOptionType)) {
                Custom.print("Mail Address", mailAddress);
            }
            if (serviceOptionType.startsWith("suica")) {
                Custom.print("Screen Title", screenTitle);
            }
            if ("waon-pc".equals(serviceOptionType) //
                    || "waon-mobile".equals(serviceOptionType)) {
                Custom.print("Cancel Limit", cancelLimit);
            }
            if ("tcc-redirect".equals(serviceOptionType)) {
                Custom.print("User Id", userId);
            }

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Order ID", resDto.getOrderId());
            Custom.print("Receipt Number", resDto.getReceiptNo());
            Custom.print("Application URL", resDto.getAppUrl());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
