package jp.veritrans.tercerog.sample.command.em;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.EmRefundRequestDto;
import jp.veritrans.tercerog.mdk.dto.EmRefundResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * EmRefundCommand : 電子マネー決済(返金申込)サンプル
 */
public class EmRefundCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // [決済方式]
        // サイバーEdy : edy-pc
        // モバイルEdy : edy-mobile
        // モバイルEdyダイレクト : edy-direct
        // モバイルSuicaメール決済 : suica-mobile-mail
        // モバイルSuicaアプリ決済 : suica-mobile-app
        // Suicaインターネット決済メール連携 : suica-pc-mail
        // Suicaインターネット決済アプリ連携 : suica-pc-app
        // WAON モバイルアプリ決済 : waon-mobile
        // WAON PaSoRi決済 : waon-pc
        String serviceOptionType = "suica-mobile-app";
        // 取引ID
        String orderID = Custom.getOrderID();
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // オーダー種別
        String orderKind = "refund";
        // 決済期限
        String settlementLimit = Custom.getPaymentLimit("yyyyMMddHHmmss", 10);
        // 画面タイトル
        String screenTitle = "For Mobile Suica";
        // 返金対象取引ID
        String refundOrderId = "set target order id";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        EmRefundRequestDto reqDto = new EmRefundRequestDto();
        // 決済方式の設定
        reqDto.setServiceOptionType(serviceOptionType);
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // オーダー種別の設定
        reqDto.setOrderKind(orderKind);
        // 金額の設定
        reqDto.setAmount(amount);
        // 取消対象の取引IDを設定
        reqDto.setRefundOrderId(refundOrderId);

        if (serviceOptionType.startsWith("suica")) {
            // Suica決済の場合

            // 決済期限の設定
            reqDto.setSettlementLimit(settlementLimit);
            // 画面タイトル の設定
            reqDto.setScreenTitle(screenTitle);

        } else if ("waon-pc".equals(serviceOptionType)) {
            // WAON PaSoRi決済の場合

            /* サンプルのためダミーURLを設定 */
            reqDto.setSuccessUrl("http://127.0.0.1/web/PaymentMethodSelect?status=success");
            reqDto.setFailureUrl("http://127.0.0.1/web/PaymentMethodSelect?status=failure");
            reqDto.setCancelUrl("http://127.0.0.1/web/PaymentMethodSelect?status=cancel");
        }

        // ---------------------------------
        // 決済実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        EmRefundResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (EmRefundResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Em(Refund) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("ServiceOptionType", serviceOptionType);
            Custom.print("Order ID", orderID);
            Custom.print("Order Kind", orderKind);
            Custom.print("Amount", amount);
            if (serviceOptionType.startsWith("suica")) {
                Custom.print("Settlement Limit", settlementLimit);
            }

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Order ID", resDto.getOrderId());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
