package jp.veritrans.tercerog.sample.command.mpi;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MpiAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.MpiAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;


/**
 * MpiAuthorizeCommand : MPI(与信)サンプル
 */
public class MpiAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------

        /**
         * オプションタイプ
         * 1. MPIサービスのみ : mpi-none
         * 2. 完全認証 : mpi-complete
         * 3. 通常認証（カード会社リスク負担） ： mpi-company
         * 4. 通常認証（カード会社、加盟店リスク負担）: mpi-merchant
         */
        String optionType = "mpi-company";

        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 与信方法(同時売上実施の有無)
        String withCapture = "false";
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // トークン
        String token = "0a812412-682c-4dad-8a5d-720caf23bca0";
        // カード番号
        // String cardNumber = "4111-1111-1111-1111";
        // カード有効期限
        // String cardExpire = "12/13";

        /**
         * HTTP User-Agent（消費者ブラウザ）
         * （実際はアプリケーションサーバから取得）
         */
        String httpUserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";

        /**
         * HTTP Accept（消費者ブラウザ）
         * （実際はアプリケーションサーバから取得）
         */
        String httpAccept = "text/*;q=0.3, text/html;q=0.7";

        /**
         * 認証後に消費者ブラウザのリダイレクト先URL(通常はECサイト側のURLを設定)
         * （このサンプルはコマンドラインテストとなりますのでダミーの値を設定）
         */
        String termUrl = "http://127.0.0.1:8080/termurl";

        //---------------------------------
        // リクエスト DTO 設定  
        //---------------------------------
        MpiAuthorizeRequestDto reqDto = new MpiAuthorizeRequestDto();
        // サービスオプションタイプの設定
        reqDto.setServiceOptionType(optionType);
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // トークンの設定
        reqDto.setToken(token);
        // カード番号の設定
        // reqDto.setCardNumber(cardNumber);
        // カード有効期限の設定
        // reqDto.setCardExpire(cardExpire);
        // UserAgentの設定
        reqDto.setHttpUserAgent(httpUserAgent);
        // Acceptの設定
        reqDto.setHttpAccept(httpAccept);
        // RedirectionURLの設定
        reqDto.setRedirectionUri(termUrl);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        MpiAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (MpiAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- MPI(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Option Type", optionType);
            Custom.print("Order ID", orderID);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);
            Custom.print("Token", token);
            // Custom.print("Card Number", cardNumber);
            // Custom.print("Card Expired Date", cardExpire);
            Custom.print("User-Agent", httpUserAgent);
            Custom.print("Accept", httpAccept);
            Custom.print("Term URL", termUrl);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Response Contents", resDto.getResResponseContents());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}
