package jp.veritrans.tercerog.sample.command.mpi;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MpiReAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.MpiReAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;


/**
 * MpiReAuthorizeCommand : MPI(再与信)サンプル
 */
public class MpiReAuthorizeCommand {

	/**
	 * コマンドテスト用メインメソッド
	 */
	public static void main(String[] args) {

		//---------------------------------
		// テスト用リクエスト電文項目設定  
		//---------------------------------

		/**
		 * オプションタイプ
		 * 1. MPIサービスのみ : mpi-none
		 * 2. 完全認証 : mpi-complete
		 * 3. 通常認証（カード会社リスク負担） ： mpi-company
		 * 4. 通常認証（カード会社、加盟店リスク負担）: mpi-merchant
		 */
		String optionType = "mpi-company";

		// 取引ID(自動生成)
	    String orderID = Custom.getOrderID();
	    // 元取引ID(再与信対象取引ID)
	    String originalOrderID = "1234567890";
		// 与信方法(同時売上実施の有無)
	    String withCapture = "false";
	    // 支払金額(自動取得)
	    String amount = Custom.getAmount();

	    /**
	     * HTTP User-Agent（消費者ブラウザ）
	     * （実際はアプリケーションサーバから取得）
	     */
	    String httpUserAgent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)";

	    /**
	     * HTTP Accept（消費者ブラウザ）
	     * （実際はアプリケーションサーバから取得）
	     */
	    String httpAccept = "text/*;q=0.3, text/html;q=0.7";
		
	    /**
	     * 認証後に消費者ブラウザのリダイレクト先URL(通常はECサイト側のURLを設定)
	     * （このサンプルはコマンドラインテストとなりますのでダミーの値を設定）
	     */
	    String termUrl = "http://127.0.0.1:8080/termurl";
	    
	    //---------------------------------
		// リクエスト DTO 設定  
		//---------------------------------
	    MpiReAuthorizeRequestDto reqDto = new MpiReAuthorizeRequestDto();
        // サービスオプションタイプの設定
       	reqDto.setServiceOptionType(optionType);
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 元オーダーIDの設定
        reqDto.setOriginalOrderId(originalOrderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // UserAgentの設定
        reqDto.setHttpUserAgent(httpUserAgent);
        // Acceptの設定
        reqDto.setHttpAccept(httpAccept);
        // RedirectionURLの設定
        reqDto.setRedirectionUri(termUrl);
		
		//---------------------------------
		// 決済実行と結果表示  
		//---------------------------------
        ITransaction tran = null;
        MpiReAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (MpiReAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- MPI(ReAuthorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Option Type", optionType);
            Custom.print("Order ID", orderID);
            Custom.print("Original Order ID", originalOrderID);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);
            Custom.print("User-Agent", httpUserAgent);
            Custom.print("Accept", httpAccept);
            Custom.print("Term URL", termUrl);
            
            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Response Contents", resDto.getResResponseContents());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
	
	}

}
