package jp.veritrans.tercerog.sample.command.paynowid;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MpiAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.MpiAuthorizeResponseDto;
import jp.veritrans.tercerog.mdk.dto.PayNowIdResponse;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * PayNowIdEntryAndMpiCommand : PayNowId(MPI＋会員入会)処理用サーブレット
 */
public class PayNowIdEntryAndMpiCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 決済サービスオプション
        String serviceOptionType = "mpi-none";
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 与信方法(同時売上実施の有無)
        String withCapture = "false";
        // 支払金額(自動取得)
        String amount = Custom.getAmount();
        // カード番号
        // String cardNumber = "4111-1111-1111-1111";
        // カード有効期限
        // String cardExpire = "12/16";
        // 支払方法
        String jpo = "10";
        // セキュリティコード
        // String securityCode = "1234";
        // トークン
        String token = "0a812412-682c-4dad-8a5d-720caf23bca0";
        // 会員ID
        String accountId = "TestAccountId";
        // 課金グループID
        String groupId = "merchant4";
        // 課金開始日
        String startDate = "20130930";
        // 課金終了日
        String endDate = "20140930";
        // 都度／初回課金金額
        String oneTimeAmount = "10";
        // 継続課金金額
        String recurringAmount = "10";
        // Accept
        String httpAccept = "TestHttpAccept";
        // UserAgent
        String httpUserAgent = "TestHttpUserAgent";

        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        MpiAuthorizeRequestDto reqDto = new MpiAuthorizeRequestDto();

        // サービスオプションタイプの設定
        reqDto.setServiceOptionType(serviceOptionType);
        // オーダーIDの設定
        reqDto.setOrderId(orderID);
        // 与信方法の設定
        reqDto.setWithCapture(withCapture);
        // 金額の設定
        reqDto.setAmount(amount);
        // カード番号の設定
        // reqDto.setCardNumber(cardNumber);
        // カード有効期限の設定
        // reqDto.setCardExpire(cardExpire);
        // ペイメントオプション(支払方法・回数)の設定
        reqDto.setJpo(jpo);
        // セキュリティコードの設定
        // reqDto.setSecurityCode(securityCode);
        // トークンの設定
        reqDto.setToken(token);
        // Acceptの設定
        reqDto.setHttpAccept(httpAccept);
        // UserAgentの設定
        reqDto.setHttpUserAgent(httpUserAgent);
        // 会員IDの設定
        reqDto.setAccountId(accountId);
        // 課金グループIDの設定
        reqDto.setGroupId(groupId);
        // 課金開始日の設定
        reqDto.setStartDate(startDate);
        // 課金終了日の設定
        reqDto.setEndDate(endDate);
        // 都度／初回課金金額の設定
        reqDto.setOneTimeAmount(oneTimeAmount);
        // 継続課金金額の設定
        reqDto.setRecurringAmount(recurringAmount);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        MpiAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (MpiAuthorizeResponseDto) tran.execute();
            PayNowIdResponse payNowIdRes = resDto.getPayNowIdResponse();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- PayNowId(MpiAuthorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("WithCapture", withCapture);
            Custom.print("Amount", amount);
            // Custom.print("Card Number", cardNumber);
            // Custom.print("Card Expired Date", cardExpire);
            Custom.print("JPO", jpo);
            // Custom.print("Security Code(CVV2)", securityCode);
            Custom.print("Token", token);
            Custom.print("HttpAccept", httpAccept);
            Custom.print("HttpUserAgent", httpUserAgent);
            Custom.print("Account ID", accountId);
            Custom.print("Group ID", groupId);
            Custom.print("Start Date", startDate);
            Custom.print("End Date", endDate);
            Custom.print("OneTimeAmount", oneTimeAmount);
            Custom.print("RecurringAmount", recurringAmount);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("PayNowId Status", (payNowIdRes != null) ? payNowIdRes.getStatus() : "I do not know status because of PayNowIdResponse is null.");
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Order ID", resDto.getOrderId());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message " + ex.getMessage());
        }
    }
}
