package jp.veritrans.tercerog.sample.command.saison;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.SaisonCaptureRequestDto;
import jp.veritrans.tercerog.mdk.dto.SaisonCaptureResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;


/**
 * SaisonCaptureCommand : 永久不滅ポイント(永久不滅ウォレット)(売上要求)サンプル
 */
public class SaisonCaptureCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        //---------------------------------
        // テスト用リクエスト電文項目設定
        //---------------------------------
        // 取引ID
        String orderId = "";
        // 決済金額
        String amount = "100";
        // 永久不滅ウォレット決済金額
        String walletAmount = "70";
        // カード決済金額
        String cardAmount = "30";
        // トークン
        String token = "0a812412-682c-4dad-8a5d-720caf23bca0";
        // カード取引ID
        String cardOrderId = "";
        // カード売上フラグ
        String withCapture = "true";


        //---------------------------------
        // リクエスト DTO 設定
        //---------------------------------
        SaisonCaptureRequestDto reqDto = new SaisonCaptureRequestDto();
        // 取引IDの設定
        reqDto.setOrderId(orderId);
        // 決済金額の設定
        reqDto.setAmount(amount);
        // 永久不滅ウォレット決済金額の設定
        reqDto.setWalletAmount(walletAmount);
        // カード決済金額の設定
        reqDto.setCardAmount(cardAmount);
        // トークンの設定
        reqDto.setToken(token);
        // カード取引IDの設定
        reqDto.setCardOrderId(cardOrderId);
        // カード売上フラグの設定
        reqDto.setWithCapture(withCapture);

        //---------------------------------
        // 決済実行と結果表示
        //---------------------------------
        ITransaction tran = null;
        SaisonCaptureResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (SaisonCaptureResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Saison(Capture) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderId);
            Custom.print("Amount", amount);
            Custom.print("Wallet Amount", walletAmount);
            Custom.print("Card Amount", cardAmount);
            Custom.print("Token", token);
            Custom.print("Card Order ID", cardOrderId);
            Custom.print("With Capture", withCapture);

            Custom.print("<< RESPONSE >>");
            Custom.print("Mstatus", resDto.getMstatus());
            Custom.print("OrderId", resDto.getOrderId());
            Custom.print("MerrMsg", resDto.getMerrMsg());
            Custom.print("VResultCode", resDto.getVResultCode());
            Custom.print("ResAuthCode", resDto.getResAuthCode());

        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }

    }

}

