package jp.veritrans.tercerog.sample.command.search;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AlipaySearchParameter;
import jp.veritrans.tercerog.mdk.dto.BankSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CarrierSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CommonSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CvsSearchParameter;
import jp.veritrans.tercerog.mdk.dto.EmSearchParameter;
import jp.veritrans.tercerog.mdk.dto.LinepaySearchParameter;
import jp.veritrans.tercerog.mdk.dto.MasterpassSearchParameter;
import jp.veritrans.tercerog.mdk.dto.OrderInfo;
import jp.veritrans.tercerog.mdk.dto.OrderInfos;
import jp.veritrans.tercerog.mdk.dto.OricoscSearchParameter;
import jp.veritrans.tercerog.mdk.dto.PaypalSearchParameter;
import jp.veritrans.tercerog.mdk.dto.ProperOrderInfo;
import jp.veritrans.tercerog.mdk.dto.ProperTransactionInfo;
import jp.veritrans.tercerog.mdk.dto.RakutenSearchParameter;
import jp.veritrans.tercerog.mdk.dto.RecruitSearchParameter;
import jp.veritrans.tercerog.mdk.dto.SaisonSearchParameter;
import jp.veritrans.tercerog.mdk.dto.SearchParameters;
import jp.veritrans.tercerog.mdk.dto.SearchRange;
import jp.veritrans.tercerog.mdk.dto.SearchRequestDto;
import jp.veritrans.tercerog.mdk.dto.SearchResponseDto;
import jp.veritrans.tercerog.mdk.dto.TransactionInfo;
import jp.veritrans.tercerog.mdk.dto.TransactionInfos;
import jp.veritrans.tercerog.mdk.dto.UpopSearchParameter;
import jp.veritrans.tercerog.mdk.dto.VirtualaccSearchParameter;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * SearchCommand : 全サービス検索処理サンプル
 */
public class SearchCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(final String[] args) {

        // 要求電文パラメータ
        // 対象リクエストID
        String requestId = "";
        // サービスタイプ
        // クレジットカード：card
        // 電子マネー：em
        // コンビニ：cvs
        // 銀行：bank
        // PayPal:paypal
        // セゾン:saison
        // キャリア:carrier
        // ショッピングクレジット:oricosc
        // 楽天:rakuten
        // リクルート:recruit
        // LINE Pay:linepay
        // MasterPass:masterpass
        // 銀行振込:virtualacc
        // Alipay:alipay
        // UPOP:upop
        String serviceTypeCard = "card";
        String serviceTypeEm = "em";
        String serviceTypeCvs = "cvs";
        String serviceTypeBank = "bank";
        String serviceTypePayPal = "paypal";
        String serviceTypeSaison = "saison";
        String serviceTypeCarrier = "carrier";
        String serviceTypeOricosc = "oricosc";
        String serviceTypeRakuten = "rakuten";
        String serviceTypeRecruit = "recruit";
        String serviceTypeLinePay = "linepay";
        String serviceTypeMasterpass = "masterpass";
        String serviceTypeVirtualacc = "virtualacc";
        String serviceTypeAlipay = "alipay";
        String serviceTypeUpop = "upop";

        // 検索最大件数
        String maxCount = "10";

        // 要求電文に条件セット
        SearchRequestDto reqDto = new SearchRequestDto();
        // 対象リクエストIDの設定
        reqDto.setRequestId(requestId);
        // サービスタイプの設定
        String[] serviceType = { serviceTypeEm };
        reqDto.setServiceTypeCd(serviceType);
        // 検索最大件数の設定
        reqDto.setMaxCount(maxCount);
        // ダミー決済も検索対象に含む
        reqDto.setContainDummyFlag("true");

        // サービス間検索条件パラメータ値
        // 取引ID
        String orderId = "dummy*";
        // 対象コマンド
        // Authorize/ReAuthorize/Capture/Cancel/Refund/Retry/Verify/Remove
        String[] command = { "Authorize", "Capture", "Cancel", "Remove", "ReAuthorize" };
        // 対象取引ステータス
        String[] mStatus = { "success", "pending", "failure" };
        // 取引日時
        String txnFromDatetime = "201001010000";
        String txnToDatetime = "201503190000";
        // 取引金額
        String amountFrom = "1";
        String amountTo = "10000";

        // 検索範囲設定：取引期間
        SearchRange txnDatetimeRange = new SearchRange();
        txnDatetimeRange.setFrom(txnFromDatetime);
        txnDatetimeRange.setTo(txnToDatetime);

        // 検索範囲設定：取引金額
        SearchRange amountRange = new SearchRange();
        amountRange.setFrom(amountFrom);
        amountRange.setTo(amountTo);

        // サービス間共通検索パラメータ設定
        CommonSearchParameter commonSearchParameter = new CommonSearchParameter();
        commonSearchParameter.setOrderId(orderId);
        commonSearchParameter.setCommand(command);
        commonSearchParameter.setMstatus(mStatus);
        commonSearchParameter.setTxnDatetime(txnDatetimeRange);
        commonSearchParameter.setAmount(amountRange);

        // 以下、サービス別指定

        // 電子マネー決済固有検索パラメータ
        // 電子マネー種別
        // edy/suica/waon/tcc
        String[] emType = { "edy", "suica", "waon", "tcc" };

        // 検索範囲設定：決済期限日時
        // 検索始点 YYYYMMDDhhmm
        String settlementFromDatetime = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String settlementToDatetime = "201003312359";
        SearchRange settlementLimitRange = new SearchRange();
        settlementLimitRange.setFrom(settlementFromDatetime);
        settlementLimitRange.setTo(settlementToDatetime);

        // 検索範囲設定：決済完了日時
        // 検索始点 YYYYMMDDhhmm
        String completeFromDatetime = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String completeToDatetime = "201004010000";
        SearchRange completeDatetimeRange = new SearchRange();
        completeDatetimeRange.setFrom(completeFromDatetime);
        completeDatetimeRange.setTo(completeToDatetime);

        EmSearchParameter emSearchParameter = new EmSearchParameter();
        emSearchParameter.setEmType(emType);
        emSearchParameter.setSettlementLimit(settlementLimitRange);
        emSearchParameter.setCompleteDatetime(completeDatetimeRange);

        // コンビニ決済固有検索パラメータ
        // コンビニ種別
        // セブンイレブン:sej
        // イーコンテキスト:econ
        // ウェルネット：other
        String[] cvsType = { "sej", "econ", "other" };

        // 検索範囲設定：支払期限日時
        // 検索始点 YYYYMMDDhhmm
        String payLimitFrom = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String payLimitTo = "201003312359";
        SearchRange payLimitRange = new SearchRange();
        payLimitRange.setFrom(payLimitFrom);
        payLimitRange.setTo(payLimitTo);

        // 検索範囲設定：入金受付日
        // 検索始点 YYYYMMDDhhmm
        String paidDatetimeFrom = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String paidDatetimeTo = "201003010000";
        SearchRange paidDatetimeRange = new SearchRange();
        paidDatetimeRange.setFrom(paidDatetimeFrom);
        paidDatetimeRange.setTo(paidDatetimeTo);

        CvsSearchParameter cvsSearchParameter = new CvsSearchParameter();
        cvsSearchParameter.setCvsType(cvsType);
        cvsSearchParameter.setPayLimit(payLimitRange);
        cvsSearchParameter.setPaidDatetime(paidDatetimeRange);

        // PayEasy決済固有検索パラメータ
        // 方式種別
        // ATM決済　：　atm
        // ネットバンク決済PC : netbank-pc
        // ネットバンク決済DoCoMo ：　netbank-docomo
        // ネットバンク決済SoftBank　：　netbank-sonftbank
        // ネットバンク決済au ： netbank-au
        String[] bankOptionType = { "atm", "netbank-pc", "netbank-docomo", "netbank-sonftbank", "netbank-au" };

        // 検索範囲設定：支払期限日時
        // 検索始点 YYYYMMDDhhmm
        String bankPayLimitFrom = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String bankPayLimitTo = "201003312359";
        SearchRange bankPayLimitRange = new SearchRange();
        bankPayLimitRange.setFrom(bankPayLimitFrom);
        bankPayLimitRange.setTo(bankPayLimitTo);

        // 検索範囲設定：入金受付日
        // 検索始点 YYYYMMDDhhmm
        String receivedDatetimeFrom = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String receivedDatetimeTo = "201003010000";
        SearchRange receivedDatetimeRange = new SearchRange();
        receivedDatetimeRange.setFrom(receivedDatetimeFrom);
        receivedDatetimeRange.setTo(receivedDatetimeTo);

        BankSearchParameter bankSearchParameter = new BankSearchParameter();
        bankSearchParameter.setOptionType(bankOptionType);
        bankSearchParameter.setPayLimit(bankPayLimitRange);
        bankSearchParameter.setReceivedDatetime(receivedDatetimeRange);

        // PayPal決済固有検索パラメータ
        // 検索範囲設定：支払日時
        // 検索始点 YYYYMMDDhhmm
        String paymentDatetimeFrom = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String paymentDatetimeTo = "201003010000";
        SearchRange paymentDatetimeRange = new SearchRange();
        paymentDatetimeRange.setFrom(paymentDatetimeFrom);
        paymentDatetimeRange.setTo(paymentDatetimeTo);

        // 顧客番号
        String payerId = "dummy";
        PaypalSearchParameter paypalSearchParameter = new PaypalSearchParameter();
        paypalSearchParameter.setPayerId(payerId);
        paypalSearchParameter.setPaymentDatetime(paymentDatetimeRange);

        // セゾン決済固有検索パラメータ
        // 検索範囲設定：合計決済金額
        SearchRange totalAmount = new SearchRange();
        totalAmount.setFrom("1");
        totalAmount.setTo("110");

        // 検索範囲設定：ウォレット決済金額
        SearchRange walletAmount = new SearchRange();
        walletAmount.setFrom("2");
        walletAmount.setTo("120");

        // 検索範囲設定：カード決済金額
        SearchRange cardAmount = new SearchRange();
        cardAmount.setFrom("3");
        cardAmount.setTo("130");

        SaisonSearchParameter saizonSearchParameter = new SaisonSearchParameter();
        saizonSearchParameter.setTotalAmount(totalAmount);
        saizonSearchParameter.setWalletAmount(walletAmount);
        saizonSearchParameter.setCardAmount(cardAmount);

        // キャリア決済固有検索パラメータ
        CarrierSearchParameter carrierSearchParameter = new CarrierSearchParameter();
        // 詳細オーダー決済状態
        carrierSearchParameter.setDetailOrderType(new String[] { "Init", "Auth" });
        // キャリアサービスタイプ
        carrierSearchParameter.setCrServiceType(new String[] { "au", "docomo" });
        // キャリアオーダーID
        //carrierSearchParameter.setCrOrderId(new String[] {});
        // 課金タイプ
        //carrierSearchParameter.setAccountingType("1");
        // 商品タイプ
        carrierSearchParameter.setItemType(new String[] { "0", "1", "2" });
        // 継続状態フラグ（月額課金状態フラグ）
        //carrierSearchParameter.setMpStatus(new String[]{});
        // 端末種別
        carrierSearchParameter.setTerminalKind(new String[] { "0", "1", "2" });
        // 詳細コマンドタイプ名
        //carrierSearchParameter.setDetailCommandType(new String[]{});
        // 初回課金年月日
        //carrierSearchParameter.setMpFirstDate(new String[]{});
        // 継続課金日
        //carrierSearchParameter.setMpDay(new String[]{});
        // 商品番号
        //carrierSearchParameter.setItemId("01234567");

        // ショッピングクレジット決済固有検索パラメータ
        OricoscSearchParameter oricosc_param = new OricoscSearchParameter();
        String oricosc_oricoOrderNo = "";
        // 支払合計金額の範囲指定パラメータを生成
        SearchRange oricosc_amountRange = new SearchRange();
        oricosc_amountRange.setFrom("1");
        oricosc_amountRange.setTo("1000");
        // 商品価格合計(税込)の範囲指定パラメータを生成
        SearchRange oricosc_totalItemAmountRange = new SearchRange();
        oricosc_totalItemAmountRange.setFrom("1");
        oricosc_totalItemAmountRange.setTo("1000");

        oricosc_param.setOricoOrderNo(oricosc_oricoOrderNo);
        oricosc_param.setAmount(oricosc_amountRange);
        oricosc_param.setTotalItemAmount(oricosc_totalItemAmountRange);

        // 楽天ID決済固有検索パラメータ
        RakutenSearchParameter rakutenSearchParameter = new RakutenSearchParameter();
        // 詳細オーダー決済状態
        rakutenSearchParameter.setDetailOrderType(new String[] { "Init", "Auth" });
        // 詳細コマンドタイプ名
        rakutenSearchParameter.setDetailCommandType(new String[] { "Init", "PreAuth" });
        // 商品ID
        rakutenSearchParameter.setItemId("12*");

        // リクルートかんたん支払い固有検索パラメータ
        RecruitSearchParameter recruitSearchParameter = new RecruitSearchParameter();
        // 詳細オーダー決済状態
        recruitSearchParameter.setDetailOrderType(new String[] { "Init", "Auth" });
        // 詳細コマンドタイプ名
        recruitSearchParameter.setDetailCommandType(new String[] { "Init", "PreAuth" });
        // 商品ID
        recruitSearchParameter.setItemId("12*");

        // LINE Pay固有検索パラメータ
        LinepaySearchParameter linepaySearchParameter = new LinepaySearchParameter();
        // 詳細オーダー決済状態
        linepaySearchParameter.setDetailOrderType(new String[] { "Init", "Auth" });
        // 詳細コマンドタイプ名
        linepaySearchParameter.setDetailCommandType(new String[] { "Init", "PreAuth" });
        // 商品ID
        linepaySearchParameter.setItemId("12*");

        // MasterPass固有検索パラメータ
        MasterpassSearchParameter masterpassSearchParameter = new MasterpassSearchParameter();
        // 詳細オーダー決済状態
        masterpassSearchParameter.setDetailOrderType(new String[] { "Init", "Auth" });
        // 詳細コマンドタイプ名
        masterpassSearchParameter.setDetailCommandType(new String[] { "Init", "Auth" });
        // 商品ID
        masterpassSearchParameter.setItemId("12*");

        // 銀行振込決済固有検索パラメータ
        VirtualaccSearchParameter virtualaccSearchParameter = new VirtualaccSearchParameter();
        // 詳細オーダー決済状態
        virtualaccSearchParameter.setDetailOrderType(new String[] { "Init", "Auth" });
        // 詳細コマンドタイプ名
        virtualaccSearchParameter.setDetailCommandType(new String[] { "Init", "Auth" });
        // 登録時振込人名
        virtualaccSearchParameter.setEntryTransferName("");
        // 登録時振込番号
        virtualaccSearchParameter.setEntryTransferNumber("");
        // 口座番号
        virtualaccSearchParameter.setAccountNumber("");

        // Alipay決済固有検索パラメータ
        AlipaySearchParameter alipaySearchParameter = new AlipaySearchParameter();
        // 詳細オーダー決済状態
        alipaySearchParameter.setDetailOrderType(new String[] { "payment", "refund" });
        // 決済センターとの取引ID
        alipaySearchParameter.setCenterTradeId("");
        // 支払い日時
        // 検索始点 YYYYMMDDhhmm
        String paymentTimeFrom = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String paymentTimeTo = "201003010000";
        SearchRange paymentTimeRange = new SearchRange();
        paymentTimeRange.setFrom(paymentTimeFrom);
        paymentTimeRange.setTo(paymentTimeTo);
        alipaySearchParameter.setPaymentTime(paymentTimeRange);
        // 清算日時
        // 検索始点 YYYYMMDDhhmm
        String settlementTimeFrom = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String settlementTimeTo = "201003010000";
        SearchRange settlementTimeRange = new SearchRange();
        settlementTimeRange.setFrom(settlementTimeFrom);
        settlementTimeRange.setTo(settlementTimeTo);
        alipaySearchParameter.setSettlementTime(settlementTimeRange);
        // 決済種別
        alipaySearchParameter.setPayType(new String[] { "0", "1", "2" });

        // 銀聯ネット決済(UPOP)固有検索パラメータ
        UpopSearchParameter upopSearchParameter = new UpopSearchParameter();
        // 決済日時(日本)
        // 検索始点 YYYYMMDDhhmm
        String settleDatetimeJpFrom = "201001010000";
        // 検索終点 YYYYMMDDhhmm
        String settleDatetimeJpTo = "201003010000";
        SearchRange settleDatetimeRangeJp = new SearchRange();
        settleDatetimeRangeJp.setFrom(settleDatetimeJpFrom);
        settleDatetimeRangeJp.setTo(settleDatetimeJpTo);
        upopSearchParameter.setSettleDatetimeJp(settleDatetimeRangeJp);
        // // 決済日時(中国)
        // // 検索始点 YYYYMMDDhhmm
        // String settleDatetimeCnFrom = "201001010000";
        // // 検索終点 YYYYMMDDhhmm
        // String settleDatetimeCnTo = "201003010000";
        // SearchRange settleDatetimeRangeCn = new SearchRange();
        // settleDatetimeRangeCn.setFrom(settleDatetimeCnFrom);
        // settleDatetimeRangeCn.setTo(settleDatetimeCnTo);
        // upopSearchParameter.setSettleDatetimeCn(settleDatetimeRangeCn);
        // 詳細オーダー決済状態
        upopSearchParameter.setDetailOrderType(new String[] { "a", "ac" });

        // 取引結果検索条件設定
        // 対象サービスの検索パラメータを必要に応じてセット
        SearchParameters searchParameters = new SearchParameters();
        // 共通パラメータの設定
        searchParameters.setCommon(commonSearchParameter);
        // 電子マネー決済取引
        // searchParameters.setEm(emSearchParameter);
        // コンビニ決済取引
        // searchParameters.setCvs(cvsSearchParameter);
        // PayEasy決済取引
        // searchParameters.setBank(bankSearchParameter);
        // PayPal決済取引
        // searchParameters.setPaypal(paypalSearchParameter);
        // Saison決済取引
        // searchParameters.setSaison(saizonSearchParameter);
        // キャリア決済取引
        // searchParameters.setCarrier(carrierSearchParameter);
        // ショッピングクレジット決済取引
        // searchParameters.setOricosc(oricosc_param);
        // 楽天ID決済取引
        // searchParameters.setRakuten(rakutenSearchParameter);
        // リクルートかんたん支払い取引
        // searchParameters.setRecruit(recruitSearchParameter);
        // LINE Pay取引
        // searchParameters.setLinepay(linepaySearchParameter);
        // MasterPass決済取引
        // searchParameters.setMasterpass(masterpassSearchParameter);
        // 銀行振込決済取引
        // searchParameters.setVirtualacc(virtualaccSearchParameter);
        // Alipay決済取引
        // searchParameters.setAlipay(alipaySearchParameter);
        // 銀聯ネット決済(UPOP)取引
        // searchParameters.setUpop(upopSearchParameter);

        // 取引結果検索条件を要求電文パラメータへ設定
        reqDto.setSearchParameters(searchParameters);

        // ---------------------------------
        // 決済実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        SearchResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (SearchResponseDto)tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- Search -*");

            Custom.print("<< REQUEST >>");
            Custom.print(reqDto.toString());

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            if (resDto.getMstatus().equals("success")) {
                OrderInfos orderInfos = resDto.getOrderInfos();
                OrderInfo[] orderInfo = orderInfos.getOrderInfo();
                int index = 0;
                if (orderInfo != null)
                    index = orderInfo.length;
                for (int i = 0; i < index; i++) {
                    Custom.print("*---------**---------*");
                    Custom.print("Index", orderInfo[i].getIndex());
                    Custom.print("Service Type", orderInfo[i].getServiceTypeCd());
                    Custom.print("Order ID", orderInfo[i].getOrderId());
                    Custom.print("Order Status", orderInfo[i].getOrderStatus());

                    ProperOrderInfo properOrderInfo = orderInfo[i].getProperOrderInfo();
                    if (orderInfo[i].getServiceTypeCd().equals("carrier")) {
                        // キャリア決済の結果
                        Custom.print("Carrier Service Type", properOrderInfo.getCrServiceType());
                        Custom.print("With Capture", properOrderInfo.getWithCapture());
                        Custom.print("Accounting Type", properOrderInfo.getAccountingType());
                        Custom.print("Item Info", properOrderInfo.getItemInfo());
                        Custom.print("Item ID", properOrderInfo.getItemId());
                        Custom.print("Item Type", properOrderInfo.getItemType());
                        Custom.print("Terminal Kind", properOrderInfo.getTerminalKind());
                        Custom.print("Authorize Datetime", properOrderInfo.getAuthorizeDatetime());
                        Custom.print("Capture Datetime", properOrderInfo.getCaptureDatetime());
                        Custom.print("Cancel Datetime", properOrderInfo.getCancelDatetime());
                        Custom.print("Monthly First Date", properOrderInfo.getMpFirstDate());
                        Custom.print("Monthly Day", properOrderInfo.getMpDay());
                        Custom.print("Monthly Status", properOrderInfo.getMpStatus());
                        Custom.print("Monthly Order ID", properOrderInfo.getMpOrderId());
                        Custom.print("Monthly Transaction Status Type", properOrderInfo.getMpTxnStatusType());
                        Custom.print("Monthly Capture Datetime", properOrderInfo.getMpCaptureDatetime());
                        Custom.print("Monthly Cancel Datetime", properOrderInfo.getMpCancelDatetime());
                        Custom.print("Monthly Terminate Datetime", properOrderInfo.getMpTerminateDatetime());
                        Custom.print("D3 Flag", properOrderInfo.getD3Flag());
                        Custom.print("Flets Area", properOrderInfo.getFletsArea());
                    } else if (orderInfo[i].getServiceTypeCd().equals("rakuten")) {
                        // 楽天ID決済の結果
                        Custom.print("With Capture", properOrderInfo.getWithCapture());
                        Custom.print("Item Name", properOrderInfo.getItemName());
                        Custom.print("Item ID", properOrderInfo.getItemId());
                        Custom.print("Authorize Amount", properOrderInfo.getAuthorizeAmount());
                        Custom.print("Balance", properOrderInfo.getBalance());
                        Custom.print("Authorize Datetime", properOrderInfo.getAuthorizeDatetime());
                        Custom.print("Rakuten Order ID", properOrderInfo.getRakutenOrderId());
                    } else if (orderInfo[i].getServiceTypeCd().equals("recruit")) {
                        // リクルートかんたん支払いの結果
                        Custom.print("With Capture", properOrderInfo.getWithCapture());
                        Custom.print("Item Name", properOrderInfo.getItemName());
                        Custom.print("Item ID", properOrderInfo.getItemId());
                        Custom.print("Authorize Amount", properOrderInfo.getAuthorizeAmount());
                        Custom.print("Balance", properOrderInfo.getBalance());
                        Custom.print("Use Point", properOrderInfo.getUsePoint());
                        Custom.print("Give Point", properOrderInfo.getGivePoint());
                        Custom.print("Authorize Datetime", properOrderInfo.getAuthorizeDatetime());
                        Custom.print("Recruit Order ID", properOrderInfo.getRecruitOrderId());
                    } else if (orderInfo[i].getServiceTypeCd().equals("linepay")) {
                        // LINE Payの結果
                        Custom.print("With Capture", properOrderInfo.getWithCapture());
                        Custom.print("Item Name", properOrderInfo.getItemName());
                        Custom.print("Item ID", properOrderInfo.getItemId());
                        Custom.print("Authorize Amount", properOrderInfo.getAuthorizeAmount());
                        Custom.print("Balance", properOrderInfo.getBalance());
                        Custom.print("Authorize Datetime", properOrderInfo.getAuthorizeDatetime());
                        Custom.print("Linepay Order ID", properOrderInfo.getLinepayOrderId());
                    } else if (orderInfo[i].getServiceTypeCd().equals("masterpass")) {
                        // MasterPass決済の結果
                        Custom.print("With Capture", properOrderInfo.getWithCapture());
                        Custom.print("Item ID", properOrderInfo.getItemId());
                        Custom.print("Item Amount", properOrderInfo.getItemAmount());
                        Custom.print("Authorize Amount", properOrderInfo.getAuthorizeAmount());
                        Custom.print("Authorize Datetime", properOrderInfo.getAuthorizeDatetime());
                        Custom.print("Masterpass Order Id", properOrderInfo.getMasterpassOrderId());
                        Custom.print("Card Order Id", properOrderInfo.getCardOrderId());
                        Custom.print("Acquirer Code", properOrderInfo.getAcquirerCode());
                        Custom.print("Card Number", properOrderInfo.getCardNumber());
                    } else if (orderInfo[i].getServiceTypeCd().equals("virtualacc")) {
                        // 銀行振込決済の結果
                        Custom.print("Total Deposit Amount", properOrderInfo.getTotalDepositAmount());
                        Custom.print("Entry Transfer Name", properOrderInfo.getEntryTransferName());
                        Custom.print("Entry Transfer Number", properOrderInfo.getEntryTransferNumber());
                        Custom.print("Accounting Type", properOrderInfo.getAccountingType());
                        Custom.print("Account Manage Type", properOrderInfo.getAccountManageType());
                    }

                    TransactionInfos transactionInfos = orderInfo[i].getTransactionInfos();
                    TransactionInfo transactionInfo[] = transactionInfos.getTransactionInfo();

                    int indexTxn = 0;
                    if (transactionInfo != null)
                        indexTxn = transactionInfo.length;
                    for (int j = 0; j < indexTxn; j++) {
                        Custom.print("----");
                        Custom.print("Transaction ID", transactionInfo[j].getTxnId());
                        Custom.print("Executed Command", transactionInfo[j].getCommand());
                        Custom.print("Transaction Status", transactionInfo[j].getMstatus());
                        Custom.print("Transaction Result Code", transactionInfo[j].getVResultCode());
                        Custom.print("Execute Time", transactionInfo[j].getTxnDatetime());
                        Custom.print("Settlement Amount", transactionInfo[j].getAmount());

                        ProperTransactionInfo properTransactionInfo = transactionInfo[j].getProperTransactionInfo();
                        if (properTransactionInfo != null) {
                            // サンプルでは、カード決済の例を実装しています
                            if (orderInfo[i].getServiceTypeCd().equals("card")) {
                                Custom.print("Card Transaction Type", properTransactionInfo.getTxnKind());
                                Custom.print("Gateway Request Date", properTransactionInfo.getGatewayRequestDate());
                                Custom.print("Gateway Response Date", properTransactionInfo.getGatewayResponseDate());
                                Custom.print("Center Request Date", properTransactionInfo.getCenterRequestDate());
                                Custom.print("Center Response Date", properTransactionInfo.getCenterRequestDate());
                                Custom.print("Center Request Number", properTransactionInfo.getCenterRequestNumber());
                                Custom.print("Center Reference Number",
                                        properTransactionInfo.getCenterReferenceNumber());
                                Custom.print("Request Auth Code", properTransactionInfo.getReqAuthCode());
                            } else if (orderInfo[i].getServiceTypeCd().equals("carrier")) {
                                // キャリア決済の結果
                                Custom.print("Carrier Result Code", properTransactionInfo.getCrResultCode());
                                Custom.print("Carrier Request Datetime", properTransactionInfo.getCrRequestDatetime());
                                Custom.print("Carrier Response Datetime", properTransactionInfo.getCrResponseDatetime());
                            } else if (orderInfo[i].getServiceTypeCd().equals("rakuten")) {
                                // 楽天ID決済の結果
                                Custom.print("Rakuten API Error Code", properTransactionInfo.getRakutenApiErrorCode());
                                Custom.print("Rakuten Order Error Code",
                                        properTransactionInfo.getRakutenOrderErrorCode());
                                Custom.print("Rakuten Request Datetime",
                                        properTransactionInfo.getRakutenRequestDatetime());
                                Custom.print("Rakuten Response Datetime",
                                        properTransactionInfo.getRakutenResponseDatetime());
                            } else if (orderInfo[i].getServiceTypeCd().equals("recruit")) {
                                // リクルートかんたん支払いの結果
                                Custom.print("Recruit Error Code", properTransactionInfo.getRecruitErrorCode());
                                Custom.print("Recruit Request Datetime",
                                        properTransactionInfo.getRecruitRequestDatetime());
                                Custom.print("Recruit Response Datetime",
                                        properTransactionInfo.getRecruitResponseDatetime());
                            } else if (orderInfo[i].getServiceTypeCd().equals("linepay")) {
                                // LINE Payの結果
                                Custom.print("Linepay Error Code", properTransactionInfo.getLinepayErrorCode());
                                Custom.print("Linepay Request Datetime",
                                        properTransactionInfo.getLinepayRequestDatetime());
                                Custom.print("Linepay Response Datetime",
                                        properTransactionInfo.getLinepayResponseDatetime());
                            } else if (orderInfo[i].getServiceTypeCd().equals("masterpass")) {
                                // MasterPass決済の結果
                                Custom.print("Masterpass AuthCode",
                                        properTransactionInfo.getAuthCode());
                                Custom.print("Masterpass ReferenceNumber",
                                        properTransactionInfo.getReferenceNumber());
                                Custom.print("Masterpass DetailCommandType",
                                        properTransactionInfo.getDetailCommandType());
                                Custom.print("Masterpass CardVResultCode",
                                        properTransactionInfo.getCardVResultCode());
                                Custom.print("Masterpass Request Datetime",
                                        properTransactionInfo.getMasterpassRequestDatetime());
                                Custom.print("Masterpass Response Datetime",
                                        properTransactionInfo.getMasterpassResponseDatetime());
                            } else if (orderInfo[i].getServiceTypeCd().equals("virtualacc")) {
                                // 銀行振込決済の結果
                                Custom.print("Virtualacc With Reconcile",
                                        properTransactionInfo.getWithReconcile());
                                Custom.print("Virtualacc Deposit Id",
                                        properTransactionInfo.getDepositId());
                                Custom.print("Virtualacc Registration Method",
                                        properTransactionInfo.getRegistrationMethod());
                                Custom.print("Virtualacc Deposit Date",
                                        properTransactionInfo.getDepositDate());
                                Custom.print("Virtualacc Transfer Name",
                                        properTransactionInfo.getTransferName());
                            } else if (orderInfo[i].getServiceTypeCd().equals("alipay")) {
                                // Alipay決済の結果
                                Custom.print("Alipay Center Trade Id",
                                        properTransactionInfo.getCenterTradeId());
                                Custom.print("Alipay Txn Type",
                                        properTransactionInfo.getAlipayTxnType());
                                Custom.print("Alipay Settle Amount",
                                        properTransactionInfo.getSettleAmount());
                                Custom.print("Alipay Settle Currency",
                                        properTransactionInfo.getSettleCurrency());
                                Custom.print("Alipay Payment Time",
                                        properTransactionInfo.getPaymentTime());
                                Custom.print("Alipay Settlement Time",
                                        properTransactionInfo.getSettlementTime());
                                Custom.print("Alipay Pay Type",
                                        properTransactionInfo.getPayType());
                            } else if (orderInfo[i].getServiceTypeCd().equals("upop")) {
                                // 銀聯ネット決済(UPOP)の結果
                                Custom.print("UPOP Settle Amount",
                                        properTransactionInfo.getResUpopSettleAmount());
                                Custom.print("UPOP Settle Date",
                                        properTransactionInfo.getResUpopSettleDate());
                                Custom.print("UPOP Settle Currency",
                                        properTransactionInfo.getResUpopSettleCurrency());
                                Custom.print("UPOP Exchange Date",
                                        properTransactionInfo.getResUpopExchangeDate());
                                Custom.print("UPOP Exchange Rate",
                                        properTransactionInfo.getResUpopExchangeRate());
                                Custom.print("UPOP Upop Order Id",
                                        properTransactionInfo.getResUpopOrderId());
                            }
                        } // ProperTransactionInfo
                    } // TransactionInfo
                } // OrderInfo
            }
        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
