package jp.veritrans.tercerog.sample.command.upop;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.UpopAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.UpopAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.util.Custom;

/**
 * UpopAuthorizeCommand : 銀聯ネット決済(UPOP)(決済申込)サンプル
 */
public class UpopAuthorizeCommand {

    /**
     * コマンドテスト用メインメソッド
     */
    public static void main(String[] args) {

        // ---------------------------------
        // テスト用リクエスト電文項目設定
        // ---------------------------------
        // 取引ID(自動生成)
        String orderID = Custom.getOrderID();
        // 金額(自動取得)
        String amount = Custom.getAmount();
        // 売上フラグ
        // "true"： 与信・売上、"false"： 与信のみ
        String withCapture = "true";
        // 決済結果戻り先URL
        String termUrl = "http://localhost/web/upop/AuthorizeResult";
        // 消費者IPアドレス
        String customerIp = "111.111.111.111";

        // ---------------------------------
        // リクエスト DTO 設定
        // ---------------------------------
        UpopAuthorizeRequestDto reqDto = new UpopAuthorizeRequestDto();
        // 取引IDの設定
        reqDto.setOrderId(orderID);
        // 金額の設定
        reqDto.setAmount(amount);
        // 売上フラグの設定
        reqDto.setWithCapture(withCapture);
        // 決済結果戻り先URLの設定
        reqDto.setTermUrl(termUrl);
        // 消費者IPアドレスの設定
        reqDto.setCustomerIp(customerIp);

        // ---------------------------------
        // 決済実行と結果表示
        // ---------------------------------
        ITransaction tran = null;
        UpopAuthorizeResponseDto resDto = null;

        try {
            tran = TransactionFactory.getInstance(reqDto);
            resDto = (UpopAuthorizeResponseDto) tran.execute();

            // リクエストとレスポンスを実行コンソール上で表示する
            Custom.print("*- UPOP(Authorize) -*");

            Custom.print("<< REQUEST >>");
            Custom.print("Order ID", orderID);
            Custom.print("Amount", amount);
            Custom.print("With Capture", withCapture);
            Custom.print("Term Url", termUrl);
            Custom.print("Customer Ip", customerIp);

            Custom.print("<< RESPONSE >>");
            Custom.print("Status", resDto.getMstatus());
            Custom.print("Message", resDto.getMerrMsg());
            Custom.print("Result Code", resDto.getVResultCode());
            Custom.print("Entry Form", resDto.getEntryForm());
            
        } catch (Exception ex) {
            Custom.print("Exception Occured !");
            Custom.print("Exception Message" + ex.getMessage());
        }
    }
}
