package jp.veritrans.tercerog.sample.push;

import java.io.BufferedReader;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.util.MdkMerchantUtility;
import jp.veritrans.tercerog.sample.util.CSVWriter;
import jp.veritrans.tercerog.sample.util.Custom;

import org.apache.commons.lang.StringUtils;

/**
 * BankPushServlet : 銀行決済(プッシュ)処理用サーブレット
 */
public class BankPushServlet extends HttpServlet {
    private static final long serialVersionUID = 1L;

    /**
     * Default constructor.
     */
    public BankPushServlet() {
    }

    /**
     * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
     */
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        System.out.println("BankPushServlet.doGet");
        doPost(request, response);
    }

    /**
     * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
     */
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        System.out.println("BankPushServlet.doPost");

        PrintWriter out = null;

        // bodyを取得
        InputStream inputStream = request.getInputStream();
        BufferedReader reader = new BufferedReader(new InputStreamReader(inputStream));
        char[] buff = new char[512];
        int readLength;
        StringBuffer sbBody = new StringBuffer();
        while ((readLength = reader.read(buff)) >= 0) {
            sbBody.append(buff, 0, readLength);
        }
        String body = sbBody.toString();
        System.out.println("body :" + body);

        // ヘッダーcontent-hmacを取得
        String contentHmac = request.getHeader("content-hmac");
        System.out.println("ContentHmac :" + contentHmac);

        try {
            // マーチャント様向けのデータかどうかを判断する
            boolean myData = MdkMerchantUtility.checkMessage(body.toString(), contentHmac);

            // マーチャント様向けのデータなので処理する
            if (myData) {

                Map map = Custom.getParametersFromBody(body.toString());
                // 送信時刻
                String pushTime = (String) map.get("pushTime");
                // 識別ID
                String pushId = (String) map.get("pushId");
                // 通知件数
                int cntNotify = Integer.parseInt((String) map.get("numberOfNotify"));
                System.out.println("File Header -- (　" + cntNotify + " )( " + pushTime + " )( " + pushId + " )");

                // 出力ディレクトリを作成する
                Locale objLcl = request.getLocale();
                ResourceBundle resourceBundle = ResourceBundle.getBundle("push", objLcl);
                String outputDirectory = (String) resourceBundle.getString("outputDirectory");
                Custom.createDirectoryIfRequired(outputDirectory);

                out = new PrintWriter(new FileOutputStream(//
                        Custom.getFilePath("Bank", outputDirectory, pushTime, pushId)));

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // CSVファイルを書き込むクラスを生成します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                CSVWriter printer = new CSVWriter(out, false, true);

                for (int g = 0; g < cntNotify; g++) {
                    String count = String.valueOf(g);
                    String padding = StringUtils.leftPad(count, 4, "0");
                    // オーダーID
                    String orderId = (String) map.get("orderId" + padding);
                    // 収納機関コード
                    String kikanNo = (String) map.get("kikanNo" + padding);
                    // 収納企業コード
                    String kigyoNo = (String) map.get("kigyoNo" + padding);
                    // 収納日時
                    String receivedDatetime = (String) map.get("rcvDate" + padding);
                    // お客様番号
                    String customerNo = (String) map.get("customerNo" + padding);
                    // 確認番号
                    String confNo = (String) map.get("confNo" + padding);
                    // 入金金額
                    String rcvAmount = (String) map.get("rcvAmount" + padding);
                    // ダミー決済フラグ
                    String dummy = (String) map.get("dummy" + padding);
                    String[] data = { orderId, kikanNo, kigyoNo, receivedDatetime, customerNo, confNo, rcvAmount, dummy };
                    // CSVファイルに書き込む
                    printer.writeln(data);
                }
                // 成功レスポンスをゲートウェイへ送信
                out.close();
                response.setStatus(HttpServletResponse.SC_OK);
            } else {
                // マーチャント様向けのデータではない
                System.out.println("Data does not belongs to me .. ");
                response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
            }
        } catch (Exception e) {
            System.out.println("Exception Occured !");
            System.out.println("Exception.getMessage(): " + e.getMessage());
            // 失敗レスポンスをゲートウェイへ送信
            response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
        }
    }
}
