package jp.veritrans.tercerog.sample.push;

import java.io.BufferedReader;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.util.MdkMerchantUtility;
import jp.veritrans.tercerog.sample.util.CSVWriter;
import jp.veritrans.tercerog.sample.util.Custom;

import org.apache.commons.lang.StringUtils;

/**
 * RakutenPushServlet : 楽天ID決済(プッシュ)処理用サーブレット
 */
public class RakutenPushServlet extends HttpServlet {
    private static final long serialVersionUID = 1L;

    /**
     * Default constructor.
     */
    public RakutenPushServlet() {
    }

    /**
     * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
     */
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        System.out.println("RakutenPushServlet.doGet");
        doPost(request, response);
    }

    /**
     * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
     */
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        System.out.println("RakutenPushServlet.doPost");

        PrintWriter out = null;

        // bodyを取得
        InputStream inputStream = request.getInputStream();
        BufferedReader reader = new BufferedReader(new InputStreamReader(inputStream));
        char[] buff = new char[512];
        int readLength;
        StringBuffer sbBody = new StringBuffer();
        while ((readLength = reader.read(buff)) >= 0) {
            sbBody.append(buff, 0, readLength);
        }
        String body = sbBody.toString();
        System.out.println("body :" + body);

        // ヘッダーcontent-hmacを取得
        String contentHmac = request.getHeader("content-hmac");
        System.out.println("ContentHmac :" + contentHmac);

        try {
            // マーチャント様向けのデータかどうかを判断する
            boolean myData = MdkMerchantUtility.checkMessage(body.toString(), contentHmac);

            // マーチャント様向けのデータなので処理する
            if (myData) {

                Map map = Custom.getParametersFromBody(body.toString());
                // 送信時刻
                String pushTime = (String) map.get("pushTime");
                // 識別ID
                String pushId = (String) map.get("pushId");
                // 通知件数
                int cntNotify = Integer.parseInt((String) map.get("numberOfNotify"));
                System.out.println("File Header -- ( " + cntNotify + " )( " + pushTime + " )( " + pushId + " )");

                // 出力ディレクトリを作成する
                Locale objLcl = request.getLocale();
                ResourceBundle resourceBundle = ResourceBundle.getBundle("push", objLcl);
                String outputDirectory = resourceBundle.getString("outputDirectory");
                Custom.createDirectoryIfRequired(outputDirectory);

                out = new PrintWriter(new FileOutputStream(//
                        Custom.getFilePath("Rakuten", outputDirectory, pushTime, pushId)));

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // CSVファイルを書き込むクラスを生成します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                CSVWriter printer = new CSVWriter(out, false, true);

                for (int g = 0; g < cntNotify; g++) {
                    String count = String.valueOf(g);
                    String padding = StringUtils.leftPad(count, 4, "0");
                    // オーダーID
                    String orderId = (String) map.get("orderId" + padding);
                    // 楽天注文番号
                    String rakutenOrderId = (String) map.get("rakutenOrderId" + padding);
                    // 通知種類
                    String txnType = (String) map.get("txnType" + padding);
                    // 発生時刻
                    String txnTime = (String) map.get("txnTime" + padding);
                    // 結果コード
                    String vResultCode = (String) map.get("vResultCode" + padding);
                    // ステータス
                    String mstatus = (String) map.get("mstatus" + padding);
                    // 残高
                    String balance = (String) map.get("balance" + padding);
                    // 利用ポイント
                    String usedPoint = (String) map.get("usedPoint" + padding);
                    // 楽天APIエラーコード
                    String apiErrorCode = (String) map.get("rakutenApiErrorCode" + padding);
                    // 楽天注文エラーコード
                    String orderErrorCode = (String) map.get("rakutenOrderErrorCode" + padding);
                    // ダミーフラグ
                    String dummy = (String) map.get("dummy" + padding);
                    String[] data = { orderId, rakutenOrderId, txnType, txnTime, vResultCode, mstatus, balance, usedPoint, apiErrorCode, orderErrorCode, dummy };
                    // CSVファイルに書き込む
                    printer.writeln(data);
                }
                // 成功レスポンスをゲートウェイへ送信
                out.close();
                response.setStatus(HttpServletResponse.SC_OK);
            } else {
                // マーチャント様向けのデータではない
                System.out.println("Data does not belongs to me .. ");
                response.setStatus(HttpServletResponse.SC_BAD_REQUEST);
            }
        } catch (Exception e) {
            System.out.println("Exception Occured !");
            System.out.println("Exception.getMessage(): " + e.getMessage());
            // 失敗レスポンスをゲートウェイへ送信
            response.setStatus(HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
        }
    }
}
