package jp.veritrans.tercerog.sample.web.carrier.base;

import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CarrierTerminateRequestDto;
import jp.veritrans.tercerog.mdk.dto.CarrierTerminateResponseDto;
import jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;
import jp.veritrans.tercerog.sample.util.CarrierUtility;
import jp.veritrans.tercerog.sample.util.Utils;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * キャリア決済 継続課金終了請求処理クラス。
 */
public abstract class AbstractTerminateExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    abstract protected String getJsp();

    abstract protected String getTerminateJsp();

    abstract protected void setCharacterEncoding(HttpServletRequest request) throws UnsupportedEncodingException;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // 文字コードの指定
        setCharacterEncoding(request);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引IDの取得
        String orderId = request.getParameter("orderId");

        // 強制解約の取得
        String force = request.getParameter("force");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            request.setAttribute("Admin", force);
            // 入力画面に戻る
            forward(request, response, getTerminateJsp());
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CarrierTerminateRequestDto reqDto = new CarrierTerminateRequestDto();

        // サービスオプションタイプ（キャリアの種類）の設定
        String strServiceOptionType = request.getParameter("serviceOptionType");
        reqDto.setServiceOptionType(strServiceOptionType);
        // 取引IDの設定
        reqDto.setOrderId(orderId);

        // docomoもしくはsb_matometeの場合のみ強制解約かどうかの設定
        if (MdkServiceConstants.CARRIER_DOCOMO.equals(strServiceOptionType) 
            || MdkServiceConstants.CARRIER_SB_MATOMETE.equals(strServiceOptionType)) {
            reqDto.setForce(force);
        }

        // sb_matometeまたはfletsまたはdocomoかつ強制解約ではない場合に端末種別を設定する。
        if (MdkServiceConstants.CARRIER_SB_MATOMETE.equals(strServiceOptionType) ||
            MdkServiceConstants.CARRIER_FLETS.equals(strServiceOptionType) ||
            MdkServiceConstants.CARRIER_DOCOMO.equals(strServiceOptionType) && !"true".equals(force)) {
            reqDto.setTerminalKind(request.getParameter("terminalKind"));
        }

        reqDto.setSuccessUrl(request.getParameter("successUrl"));
        reqDto.setCancelUrl(request.getParameter("cancelUrl"));
        reqDto.setErrorUrl(request.getParameter("errorUrl"));
        reqDto.setPushUrl(request.getParameter("pushUrl"));

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            CarrierTerminateResponseDto resDto = (CarrierTerminateResponseDto)tran.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());
            request.setAttribute("terminateDatetime", resDto.getTerminateDatetime());

            String responseContents = resDto.getResponseContents();
            if (!Utils.isNull(responseContents) && Utils.isNull(request.getAttribute("Admin"))) {
                // レスポンスコンテンツがある場合はそのまま表示します。
                // キャリアによって文字コードが異なるため、ここで文字コードを指定してください。
                response.setContentType("text/html; charset="
                        + CarrierUtility.getEncoding(strServiceOptionType, reqDto.getTerminalKind()));
                PrintWriter writer = response.getWriter();
                writer.println(responseContents);
            } else {
                // 結果画面を表示します
                forward(request, response, getJsp());
            }

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, getJsp());
        }
    }

}
