package jp.veritrans.tercerog.sample.web.cvs;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CvsCancelRequestDto;
import jp.veritrans.tercerog.mdk.dto.CvsCancelResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * コンビニ決済 取消請求処理クラス。
 */
public class CancelExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータの取得。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 決済サービスオプション
        String serviceOptionType = request.getParameter("serviceOptionType");
        // 取引ID
        String orderId = request.getParameter("orderId");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }
        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Cancel.jsp");
            return;
        }


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        CvsCancelRequestDto reqDto = new CvsCancelRequestDto();
        // 取引IDの設定
        // パラメタから取得した値を設定
        reqDto.setServiceOptionType(serviceOptionType);
        reqDto.setOrderId(orderId);


        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            CvsCancelResponseDto resDto = (CvsCancelResponseDto) transaction.execute();

            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg",  resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());

            // 結果画面を表示します
            forward(request, response, "./CancelExec.jsp");

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./CancelExec.jsp");
        }



    }



}
