package jp.veritrans.tercerog.sample.web.em;

import java.io.IOException;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.EmAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.EmAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 電子マネー決済処理クラス。
 */
public class AuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 決済サービスオプション
        String serviceOptionType = request.getParameter("serviceOptionType");
        // 決済金額
        String amount = request.getParameter("amount");
        // 決済期限
        String settlementLimit = request.getParameter("settlementLimit");
        // 支払取消期限
        String cancelLimit = request.getParameter("cancelLimit");
        // メールアドレス
        String mailAddr = request.getParameter("mailAddress");
        // ユーザID
        String userId = request.getParameter("userId");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)) {
            warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }
        if ("edy-pc".equals(serviceOptionType) //
                || "edy-direct".equals(serviceOptionType) //
                || "tcc-redirect".equals(serviceOptionType)) {
            // サイバーEdy、モバイルEdyダイレクト、nanaco決済の場合は指定不要
            if (isNull(settlementLimit) == false) {
                warning = "<font color='#ff0000'><b>決済期限は指定できません</b></font>";
            }
        } else {
            if (isNull(settlementLimit) == true) {
                warning = "<font color='#ff0000'><b>必須項目：決済期限が指定されていません</b></font>";
            }
        }
        if ("waon-pc".equals(serviceOptionType) //
                || "waon-mobile".equals(serviceOptionType)) {
            // WAON決済のみ必須
            if (isNull(cancelLimit) == true) {
                warning = "<font color='#ff0000'><b>必須項目：支払取消期限が指定されていません</b></font>";
            }
        } else {
            if (isNull(cancelLimit) == false) {
                warning = "<font color='#ff0000'><b>支払取消期限は指定できません</b></font>";
            }
        }
        if (!"edy-pc".equals(serviceOptionType) //
                && !"edy-direct".equals(serviceOptionType) //
                && !"suica-mobile-app".equals(serviceOptionType) //
                && !"suica-pc-app".equals(serviceOptionType) //
                && !"tcc-redirect".equals(serviceOptionType) //
                && isNull(mailAddr) == true) {
            warning = "<font color='#ff0000'><b>必須項目：メールアドレスが指定されていません</b></font>";
        }
        // nanaco決済のみ必須
        if ("tcc-redirect".equals(serviceOptionType)) {
            // ユーザID
            if (isNull(userId) == true) {
                warning = "<font color='#ff0000'><b>必須項目：ユーザIDが指定されていません</b></font>";
            }
        } else {
            if (isNull(userId) == false) {
                warning = "<font color='#ff0000'><b>ユーザIDは指定できません</b></font>";
            }
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./Authorize.jsp");
            return;
        }

        ResourceBundle rb = ResourceBundle.getBundle("em");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        EmAuthorizeRequestDto reqDto = new EmAuthorizeRequestDto();
        // 取引IDの採番と設定
        reqDto.setOrderId(orderId);

        if (serviceOptionType.startsWith("suica")) {
            // Suica決済の場合
            reqDto.setScreenTitle("SampleTitle");

        } else if ("waon-pc".equals(serviceOptionType)) {
            // WAON PaSoRi決済の場合
            reqDto.setCancelLimit(cancelLimit);

            /* サンプルのためダミーURLを設定 */
            reqDto.setSuccessUrl(response.encodeURL("http://127.0.0.1/web/PaymentMethodSelect?status=success"));
            reqDto.setFailureUrl(response.encodeURL("http://127.0.0.1/web/PaymentMethodSelect?status=failure"));
            reqDto.setCancelUrl(response.encodeURL("http://127.0.0.1/web/PaymentMethodSelect?status=cancel"));

        } else if ("waon-mobile".equals(serviceOptionType)) {
            // WAON モバイルアプリ決済の場合
            reqDto.setCancelLimit(cancelLimit);

        } else if ("tcc-redirect".equals(serviceOptionType)) {
            // nanaco決済の場合
            reqDto.setTransactionKind("02"); // 02:電子マネー固定
            reqDto.setUserId(userId);
            reqDto.setCompleteNoticeUrl(response.encodeURL(rb.getString("tcc.completeNoticeUrl")));
        }

        // パラメタから取得した値を設定
        reqDto.setServiceOptionType(serviceOptionType);
        reqDto.setAmount(amount);
        reqDto.setSettlementLimit(settlementLimit);
        reqDto.setCancelLimit(cancelLimit);
        if (!"edy-pc".equals(serviceOptionType) //
                && !"edy-direct".equals(serviceOptionType) //
                && !"suica-mobile-app".equals(serviceOptionType) //
                && !"suica-pc-app".equals(serviceOptionType) //
                && !"tcc-redirect".equals(serviceOptionType)) {
            reqDto.setMailAddr(mailAddr);
        }

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(reqDto);
            EmAuthorizeResponseDto resDto = (EmAuthorizeResponseDto) transaction.execute();

            request.setAttribute("orderKind", "authorize");
            request.setAttribute("serviceOptionType", serviceOptionType);
            request.setAttribute("mailAddress", mailAddr);
            request.setAttribute("orderId", resDto.getOrderId());
            request.setAttribute("amount", amount);
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg() != null ? resDto.getMerrMsg() : "");
            request.setAttribute("vResultCode", resDto.getVResultCode() != null ? resDto.getVResultCode() : "");
            request.setAttribute("receiptNo", resDto.getReceiptNo() != null ? resDto.getReceiptNo() : "");
            request.setAttribute("appUrl", resDto.getAppUrl() != null ? resDto.getAppUrl() : "");
            request.setAttribute("settlementLimit", settlementLimit);

            if ("tcc-redirect".equals(serviceOptionType)) {
                if ("success".equals(resDto.getMstatus())) {
                    // nanaco決済の場合はリダイレクト
                    response.setStatus(HttpServletResponse.SC_MOVED_PERMANENTLY);
                    response.setHeader("Location", resDto.getAppUrl());
                } else {
                    // 結果画面を表示します
                    forward(request, response, "./AuthorizeExec.jsp");
                }
            } else {
                // 結果画面を表示します
                forward(request, response, "./AuthorizeExec.jsp");
            }

        } catch (Exception ex) {
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./AuthorizeExec.jsp");
        }
    }
}
