package jp.veritrans.tercerog.sample.web.mpi;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.SearchRequestDto;
import jp.veritrans.tercerog.mdk.dto.SearchResponseDto;
import jp.veritrans.tercerog.mdk.dto.OrderInfos;
import jp.veritrans.tercerog.mdk.dto.OrderInfo;
import jp.veritrans.tercerog.mdk.dto.TransactionInfos;
import jp.veritrans.tercerog.mdk.dto.TransactionInfo;
import jp.veritrans.tercerog.mdk.dto.ProperTransactionInfo;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * クレジットカード（本人認証あり）決済のサーチ処理クラス。
 */
public class SearchExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {

        // オーダーIDの取得
        String orderId = (String) request.getParameter("orderId");
        // リクエストの取得
        String requestId = (String) request.getParameter("RequestId");
        // 決済種別の取得
        HttpSession session = request.getSession();
        String paymentMode = (String) session.getAttribute("paymentMode");

        String reAuthorizeStr = "与信";
        if ("1".equals((String) session.getAttribute("reAuthorizeFlg"))) {
            reAuthorizeStr = "再与信";
        }
        request.setAttribute("reAuthorizeStr", reAuthorizeStr);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        SearchRequestDto reqDto = new SearchRequestDto();

        // 検索用リクエストパラメータを設定
        reqDto.setRequestId(requestId);
        reqDto.setNewerFlag("false");

        // 検索結果用項目
        String mStatus = "";
        String errMsg = "";

        // MPI認証結果用項目
        String mStatusMPI = "";
        String vResultCodeMPI = "";
        long txnIdMPI = 0;

        // カード決済結果用項目
        String mStatusCard = "";
        String vResultCodeCard = "";
        long txnIdCard = 0;

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            SearchResponseDto resDto = (SearchResponseDto) tran.execute();

            mStatus = resDto.getMstatus();
            request.setAttribute("mStatus", resDto.getMstatus());
            request.setAttribute("mErrMsg", resDto.getMerrMsg());
            request.setAttribute("vResultCode", resDto.getVResultCode());

            if (mStatus.equals("success")) {
                // サーチ処理が成功しているため、何もしない
            } else {
                // サーチ処理が失敗しているため、失敗画面を表示します
                errMsg = "サーチ処理が失敗しました。";
                request.setAttribute("errMsg", errMsg);
                getServletContext().getRequestDispatcher("/mpi/SearchExec.jsp").forward(request,response);
            }

            // MPI認証結果とカード決済結果を取得します
            OrderInfos orderInfos = resDto.getOrderInfos();
            OrderInfo[] orderInfo = orderInfos.getOrderInfo();
            if (orderInfo[0].getOrderId() != null && 0 < orderInfo[0].getOrderId().length()) {
                orderId = orderInfo[0].getOrderId();
            }
            TransactionInfos transactionInfos = orderInfo[0].getTransactionInfos();
            TransactionInfo transactionInfo[] = transactionInfos.getTransactionInfo();

            int index = 0;
            if (transactionInfo != null) index = transactionInfo.length;
            long bufTxnId = 0;
            String bufTxnKind = "";
            String bufMStatus = "";
            String bufVResultCode = "";
            for (int i = 0; i < index; i++) {
                bufTxnId = Long.valueOf(transactionInfo[i].getTxnId()).longValue();
                bufMStatus = transactionInfo[i].getMstatus();
                bufVResultCode = transactionInfo[i].getVResultCode();

                ProperTransactionInfo properTransactionInfo = transactionInfo[i].getProperTransactionInfo();
                if (properTransactionInfo != null) {
                    bufTxnKind = properTransactionInfo.getTxnKind();
                    // MPI認証結果かカード決済結果の詳細項目を取得する場合は、
                    // ここでgetメソッドを活用してください。
                    //properTransactionInfo.getAmount();
                    //properTransactionInfo.getCardTransactionType();
                    //properTransactionInfo.getCenterMessages();
                    //......
                }

                // MPI～カード決済までが実行された場合
                // このタイミングでリクエストIDによる検索を実行すると
                // txnKindが"mpi"と"card"のレコードがそれぞれ１件取得できる

                // MPI認証結果(複数件ある場合は最新の一件を取得)
                if (bufTxnKind != null && bufTxnKind.equals("mpi")) {
                    if (bufTxnId > txnIdMPI) {
                        mStatusMPI = bufMStatus;
                        vResultCodeMPI = bufVResultCode;
                        txnIdMPI = bufTxnId;
                    }
                }

                // カード決済結果(最新の一件を取得)
                if (bufTxnKind != null && bufTxnKind.equals("card")) {
                    if (bufTxnId > txnIdCard) {
                        mStatusCard = bufMStatus;
                        vResultCodeCard = bufVResultCode;
                        txnIdCard = bufTxnId;
                    }
                }
            }
            // ログ
            System.out.println("PaymentMode["+paymentMode+"]: mStatusMPI="+mStatusMPI);
            System.out.println("  vResultCodeMPI="+vResultCodeMPI+", vResultCodeCard="+vResultCodeCard);

            // 結果画面で表示する内容をセット
            request.setAttribute("orderId", orderId);

            // 完了画面に表示するのは基本、本人認証の結果コードとなる。
            request.setAttribute("mStatus", mStatusMPI);
            request.setAttribute("vResultCode", vResultCodeMPI);

            // 本人認証に成功した場合、mStatusMPI の値は "success" になります
            if ("success".equals(mStatusMPI)) {
                
                // 本人認証成功で、決済種別＝「3D-Secure認証のみ(決済しない)」以外の
                // 場合、カード決済まで行われているため、完了画面に表示するのはカード決済の
                // 結果コードを表示する、というケース
                if (!"1".equals(paymentMode)) {

                    request.setAttribute("mStatus", mStatusCard);
                    request.setAttribute("vResultCode", vResultCodeCard);
                }
            } else {
                errMsg = "本人認証に失敗しました";
                request.setAttribute("errMsg", errMsg);
            }

            // 遷移
            getServletContext().getRequestDispatcher("/mpi/SearchExec.jsp").forward(request,response);

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、
            // Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            errMsg = "Exception Occured : " + ex.getMessage();
            request.setAttribute("mErrMsg", errMsg);
            getServletContext().getRequestDispatcher("/mpi/SearchExec.jsp").forward(request,response);
        }

    }
}
