package jp.veritrans.tercerog.sample.web.oricosc.base;

import java.io.IOException;
import java.io.PrintWriter;
import java.io.UnsupportedEncodingException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.OricoscAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.OricoscAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * ショッピングクレジット決済処理クラス。
 */
public abstract class AbstractAuthorizeExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    abstract protected String getJsp();
    abstract protected String getJspResult();
    abstract protected String getMerchantRedirectionUrl();
    abstract protected void setCharacterEncoding(HttpServletRequest request) throws UnsupportedEncodingException;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        // 文字コードの指定
        setCharacterEncoding(request);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 注文番号
        String oricoOrderNo = request.getParameter("oricoOrderNo");
        // 会員番号(加盟店)
        String userNo = request.getParameter("userNo");
        // 商品名１
        String itemName1 = request.getParameter("itemName1");
        // 数量１
        String itemCount1 = request.getParameter("itemCount1");
        // 商品価格１(税込)
        String itemAmount1 = request.getParameter("itemAmount1");
        // 商品名２
        String itemName2 = request.getParameter("itemName2");
        // 数量２
        String itemCount2 = request.getParameter("itemCount2");
        // 商品価格２(税込)
        String itemAmount2 = request.getParameter("itemAmount2");
        // 商品名３
        String itemName3 = request.getParameter("itemName3");
        // 数量３
        String itemCount3 = request.getParameter("itemCount3");
        // 商品価格３(税込)
        String itemAmount3 = request.getParameter("itemAmount3");
        // 商品名４
        String itemName4 = request.getParameter("itemName4");
        // 数量４
        String itemCount4 = request.getParameter("itemCount4");
        // 商品価格４(税込)
        String itemAmount4 = request.getParameter("itemAmount4");
        // 商品名５
        String itemName5 = request.getParameter("itemName5");
        // 数量５
        String itemCount5 = request.getParameter("itemCount5");
        // 商品価格５(税込)
        String itemAmount5 = request.getParameter("itemAmount5");
        // 商品価格合計(税込)
        String totalItemAmount = request.getParameter("totalItemAmount");
        // 送料合計(税込)
        String totalCarriage = request.getParameter("totalCarriage");
        // 支払金額合計
        String amount = request.getParameter("amount");
        // 頭金
        String deposit = request.getParameter("deposit");
        // 配送先郵便番号
        String shippingZipCode = request.getParameter("shippingZipCode");
        // 取扱契約番号
        String handlingContractNo = request.getParameter("handlingContractNo");
        // 契約書有無区分
        String contractDocumentKbn = request.getParameter("contractDocumentKbn");
        // WEB申込商品ID
        String webDescriptionId = request.getParameter("webDescriptionId");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(oricoOrderNo)) {
            warning =  "<font color='#ff0000'><b>必須項目：注文番号が指定されていません</b></font>";
        } else if (isNull(shippingZipCode)) {
            warning =  "<font color='#ff0000'><b>必須項目：配送先郵便番号が指定されていません</b></font>";
        } else if (isNull(itemName1)) {
            warning =  "<font color='#ff0000'><b>必須項目：商品名１が指定されていません</b></font>";
        } else if (isNull(itemCount1)) {
            warning =  "<font color='#ff0000'><b>必須項目：数量１が指定されていません</b></font>";
        } else if (isNull(itemAmount1)) {
            warning =  "<font color='#ff0000'><b>必須項目：商品価格１(税込)が指定されていません</b></font>";
        } else if (!isNum(itemCount1)) {
            warning =  "<font color='#ff0000'><b>数量１は数値で入力しなければなりません</b></font>";
        } else if (!isNum(itemAmount1)) {
            warning =  "<font color='#ff0000'><b>商品価格１(税込)は数値で入力しなければなりません</b></font>";
        } else if (isNull(totalItemAmount)) {
            warning =  "<font color='#ff0000'><b>必須項目：商品価格合計(税込)が指定されていません</b></font>";
        } else if (!isNum(totalItemAmount)) {
            warning =  "<font color='#ff0000'><b>商品価格合計(税込)は数値で入力しなければなりません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：支払金額合計が指定されていません</b></font>";
        } else if (!isNum(amount)) {
            warning =  "<font color='#ff0000'><b>支払金額合計は数値で入力しなければなりません</b></font>";
        }


        // 商品２の整合性チェック
        if (isNull(warning)) {
            if (!isNull(itemName2)) {
                if (isNull(itemCount2)) {
                    warning =  "<font color='#ff0000'><b>数量２が指定されていません</b></font>";
                } else if (isNull(itemAmount2)) {
                    warning =  "<font color='#ff0000'><b>商品価格２(税込)が指定されていません</b></font>";
                }
            } else if (!isNull(itemCount2)) {
                if (isNull(itemName2)) {
                    warning =  "<font color='#ff0000'><b>商品名２が指定されていません</b></font>";
                } else if (isNull(itemAmount2)) {
                    warning =  "<font color='#ff0000'><b>商品価格２(税込)が指定されていません</b></font>";
                }
            } else if (!isNull(itemAmount2)) {
                if (isNull(itemName2)) {
                    warning =  "<font color='#ff0000'><b>商品名２が指定されていません</b></font>";
                } else if (isNull(itemCount2)) {
                    warning =  "<font color='#ff0000'><b>数量２(税込)が指定されていません</b></font>";
                }
            }
        }

        // 商品３の整合性チェック
        if (isNull(warning)) {
            if (!isNull(itemName3)) {
                if (isNull(itemCount3)) {
                    warning =  "<font color='#ff0000'><b>数量３が指定されていません</b></font>";
                } else if (isNull(itemAmount3)) {
                    warning =  "<font color='#ff0000'><b>商品価格３(税込)が指定されていません</b></font>";
                }
            } else if (!isNull(itemCount3)) {
                if (isNull(itemName3)) {
                    warning =  "<font color='#ff0000'><b>商品名３が指定されていません</b></font>";
                } else if (isNull(itemAmount3)) {
                    warning =  "<font color='#ff0000'><b>商品価格３(税込)が指定されていません</b></font>";
                }
            } else if (!isNull(itemAmount3)) {
                if (isNull(itemName3)) {
                    warning =  "<font color='#ff0000'><b>商品名３が指定されていません</b></font>";
                } else if (isNull(itemCount3)) {
                    warning =  "<font color='#ff0000'><b>数量３(税込)が指定されていません</b></font>";
                }
            }
        }

        // 商品４の整合性チェック
        if (isNull(warning)) {
            if (!isNull(itemName4)) {
                if (isNull(itemCount4)) {
                    warning =  "<font color='#ff0000'><b>数量４が指定されていません</b></font>";
                } else if (isNull(itemAmount4)) {
                    warning =  "<font color='#ff0000'><b>商品価格４(税込)が指定されていません</b></font>";
                }
            } else if (!isNull(itemCount4)) {
                if (isNull(itemName4)) {
                    warning =  "<font color='#ff0000'><b>商品名４が指定されていません</b></font>";
                } else if (isNull(itemAmount4)) {
                    warning =  "<font color='#ff0000'><b>商品価格４(税込)が指定されていません</b></font>";
                }
            } else if (!isNull(itemAmount4)) {
                if (isNull(itemName4)) {
                    warning =  "<font color='#ff0000'><b>商品名４が指定されていません</b></font>";
                } else if (isNull(itemCount4)) {
                    warning =  "<font color='#ff0000'><b>数量４(税込)が指定されていません</b></font>";
                }
            }
        }

        // 商品５の整合性チェック
        if (isNull(warning)) {
            if (!isNull(itemName5)) {
                if (isNull(itemCount5)) {
                    warning =  "<font color='#ff0000'><b>数量５が指定されていません</b></font>";
                } else if (isNull(itemAmount5)) {
                    warning =  "<font color='#ff0000'><b>商品価格５(税込)が指定されていません</b></font>";
                }
            } else if (!isNull(itemCount5)) {
                if (isNull(itemName5)) {
                    warning =  "<font color='#ff0000'><b>商品名５が指定されていません</b></font>";
                } else if (isNull(itemAmount5)) {
                    warning =  "<font color='#ff0000'><b>商品価格５(税込)が指定されていません</b></font>";
                }
            } else if (!isNull(itemAmount5)) {
                if (isNull(itemName5)) {
                    warning =  "<font color='#ff0000'><b>商品名５が指定されていません</b></font>";
                } else if (isNull(itemCount5)) {
                    warning =  "<font color='#ff0000'><b>数量５(税込)が指定されていません</b></font>";
                }
            }
        }


        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, getJsp());
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        OricoscAuthorizeRequestDto reqDto = new OricoscAuthorizeRequestDto();
        // 取引ID
        reqDto.setOrderId(orderId);
        // 注文番号
        reqDto.setOricoOrderNo(oricoOrderNo);
        // 会員番号(加盟店)
        reqDto.setUserNo(userNo);
        // 商品名１
        reqDto.setItemName1(itemName1);
        // 数量１
        reqDto.setItemCount1(itemCount1);
        // 商品価格１(税込)
        reqDto.setItemAmount1(itemAmount1);
        // 商品名２
        reqDto.setItemName2(itemName2);
        // 数量２
        reqDto.setItemCount2(itemCount2);
        // 商品価格２(税込)
        reqDto.setItemAmount2(itemAmount2);
        // 商品名３
        reqDto.setItemName3(itemName3);
        // 数量３
        reqDto.setItemCount3(itemCount3);
        // 商品価格３(税込)
        reqDto.setItemAmount3(itemAmount3);
        // 商品名４
        reqDto.setItemName4(itemName4);
        // 数量４
        reqDto.setItemCount4(itemCount4);
        // 商品価格４(税込)
        reqDto.setItemAmount4(itemAmount4);
        // 商品名５
        reqDto.setItemName5(itemName5);
        // 数量５
        reqDto.setItemCount5(itemCount5);
        // 商品価格５(税込)
        reqDto.setItemAmount5(itemAmount5);
        // 商品価格合計(税込)
        reqDto.setTotalItemAmount(totalItemAmount);
        // 送料合計(税込)
        reqDto.setTotalCarriage(totalCarriage);
        // 支払金額合計
        reqDto.setAmount(amount);
        // 頭金
        reqDto.setDeposit(deposit);
        // 配送先郵便番号
        reqDto.setShippingZipCode(shippingZipCode);
        // マーチャントリダイレクションURL
        reqDto.setMerchantRedirectionUrl(response.encodeURL(getMerchantRedirectionUrl()));
        // 取扱契約番号
        reqDto.setHandlingContractNo(handlingContractNo);
        // 契約書有無区分
        reqDto.setContractDocumentKbn(contractDocumentKbn);
        // WEB申込商品ID
        reqDto.setWebDescriptionId(webDescriptionId);

        PrintWriter out = null;
        try {
            // HTTPレスポンスのContent-Typeに"Shift-JIS"を指定してください。
            response.setContentType("text/html; charset=Shift-JIS");
            out = response.getWriter();

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            OricoscAuthorizeResponseDto resDto = (OricoscAuthorizeResponseDto) tran.execute();

            if ("success".equals(resDto.getMstatus())) {
                String responseHtml = resDto.getResResponseContents();
                out.println(responseHtml);
                return;
            } else {
                request.setAttribute("processName", "画面表示");
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());
                request.setAttribute("vResultCode", resDto.getVResultCode());
                forward(request, response, getJspResult());
                return;
            }
        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、
            // Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, getJspResult());
            return;
        } finally {
            if (out != null) {
                out.close();
            }
        }
    }

    /**
     * 文字列が数値であることをチェック。
     * @param num 検査する文字列
     * @return 数値の場合はtrue
     */
    private boolean isNum(String num) {
        if (num == null || num.length() == 0) {
            return true;
        }
        try {
            Integer.parseInt(num);
        } catch (NumberFormatException e) {
            return false;
        }
        return true;
    }
}
