package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;
import java.util.HashMap;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardInfo;
import jp.veritrans.tercerog.mdk.dto.CardInfoAddRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoAddResponseDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoDeleteRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoDeleteResponseDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoGetRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoGetResponseDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoUpdateRequestDto;
import jp.veritrans.tercerog.mdk.dto.CardInfoUpdateResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * カード登録・更新・削除処理クラス
 */
public class CardManageExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        HttpSession session = request.getSession(true);
        String warning = null;
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 処理モードの取得
        String execMode = request.getParameter("execMode");
        // 会員IDの取得
        String accountId = request.getParameter("accountId");
        // カード選択
        String cardSelect = request.getParameter("cardSelect");
        session.setAttribute("cardSelect", cardSelect);
        // トークンの取得
        String token = request.getParameter("token");

        if ("1".equals(execMode)) {

            // カード情報取得  //

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (isNull(accountId) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
            }

            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./CardManage.jsp");
                return;
            }
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            CardInfoGetRequestDto reqDto = new CardInfoGetRequestDto();
            reqDto.setAccountId(accountId);

            try {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                CardInfoGetResponseDto resDto = (CardInfoGetResponseDto) tran.execute();

                // 処理結果を取得する
                String mStatus = resDto.getMstatus();

                if ("success".equals(mStatus)) {
                    CardInfo[] cardInfos = resDto.getPayNowIdResponse().getAccount().getCardInfo();
                    HashMap map = new HashMap();

                    // カード情報分繰り返す
                    for (int i=0; i < cardInfos.length; i++) {
                        map.put(cardInfos[i].getCardId(),
                                cardInfos[i].getCardNumber() + "：" + cardInfos[i].getCardExpire());
                    }
                    session.setAttribute("cardList", map);
                    session.setAttribute("cardSelect", "");

                     // 結果画面を表示します
                    forward(request, response, "./CardManage.jsp");

                } else {
                    if (resDto.getPayNowIdResponse() != null) {
                        request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                        request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                    }
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());
                    forward(request, response, "./CardManageExec.jsp");
                }
            } catch (Exception ex) {
                // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                System.out.println("Exception Occured !");
                System.out.println("Exception Message: " + ex.getMessage());
                ex.printStackTrace();
                request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                forward(request, response, "./CardManageExec.jsp");
            }

        } else if ("2".equals(execMode)){

            // カード削除処理 //

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (isNull(accountId) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
            }
            // カード選択
            if (isNull(cardSelect) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：削除対象カードを選択してください</b></font>";
            }

            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./CardManage.jsp");
                return;
            }
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            CardInfoDeleteRequestDto reqDto = new CardInfoDeleteRequestDto();
            reqDto.setAccountId(accountId);
            reqDto.setCardId(cardSelect);
            reqDto.setToken(token);

            try {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                CardInfoDeleteResponseDto resDto = (CardInfoDeleteResponseDto) tran.execute();
                if (resDto.getPayNowIdResponse() != null) {
                    request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                    request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                }
                request.setAttribute("vResultCode", resDto.getVResultCode());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());

                // 結果画面を表示します
                forward(request, response, "./CardManageExec.jsp");

            } catch (Exception ex) {
                // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                System.out.println("Exception Occured !");
                System.out.println("Exception Message: " + ex.getMessage());
                ex.printStackTrace();
                request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                forward(request, response, "./CardManageExec.jsp");
            }

        } else if ("3".equals(execMode)){

            // カード登録  //

            if ("".equals(cardSelect)) {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 入力をチェックします
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 会員ID
                if (isNull(accountId) == true) {
                    warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                }

                // エラー時の処理
                if (isNull(warning) == false) {
                    request.setAttribute("warning", warning);
                    // 入力画面に戻る
                    forward(request, response, "./CardManage.jsp");
                    return;
                }
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 要求DTOを生成し、値を設定します
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                CardInfoAddRequestDto reqDto = new CardInfoAddRequestDto();
                reqDto.setAccountId(accountId);
                reqDto.setCardId(cardSelect);
                reqDto.setToken(token);

                try {
                    // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                    // コマンドを実行し、応答DTOを取得します
                    // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                    ITransaction tran = TransactionFactory.getInstance(reqDto);
                    CardInfoAddResponseDto resDto = (CardInfoAddResponseDto) tran.execute();
                    if (resDto.getPayNowIdResponse() != null) {
                        request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                        request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                    }
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());

                    // 結果画面を表示します
                    forward(request, response, "./CardManageExec.jsp");

                } catch (Exception ex) {
                    // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                    System.out.println("Exception Occured !");
                    System.out.println("Exception Message: " + ex.getMessage());
                    ex.printStackTrace();
                    request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                    forward(request, response, "./CardManageExec.jsp");
                }
            } else {

            // カード更新 //

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 入力をチェックします
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 会員ID
                if (isNull(accountId) == true) {
                    warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                }
                // エラー時の処理
                if (isNull(warning) == false) {
                    request.setAttribute("warning", warning);
                    // 入力画面に戻る
                    forward(request, response, "./CardManage.jsp");
                    return;
                }
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 要求DTOを生成し、値を設定します
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                CardInfoUpdateRequestDto reqDto = new CardInfoUpdateRequestDto();
                reqDto.setAccountId(accountId);
                reqDto.setCardId(cardSelect);
                reqDto.setToken(token);

                try {
                    // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                    // コマンドを実行し、応答DTOを取得します
                    // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                    ITransaction tran = TransactionFactory.getInstance(reqDto);
                    CardInfoUpdateResponseDto resDto = (CardInfoUpdateResponseDto) tran.execute();
                    if (resDto.getPayNowIdResponse() != null) {
                        request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                        request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                    }
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());

                    // 結果画面を表示します
                    forward(request, response, "./CardManageExec.jsp");

                } catch (Exception ex) {
                    // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                    System.out.println("Exception Occured !");
                    System.out.println("Exception Message: " + ex.getMessage());
                    ex.printStackTrace();
                    request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                    forward(request, response, "./CardManageExec.jsp");
                }
            }
        } else {
            warning =  "<font color='#ff0000'><b>不正な処理です</b></font>";
            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./CardManage.jsp");
                return;
            }
        }
    }
}
