package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.ResourceBundle;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.MpiAuthorizeRequestDto;
import jp.veritrans.tercerog.mdk.dto.MpiAuthorizeResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * MPI処理クラス
 */
public class MpiAuthorizeExec extends MdkSampleBaseServlet {


    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request,
            HttpServletResponse response) throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 設定ファイルより取得する。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // paynowid.propertiesファイルから必要なプロパティを取得
        Locale objLcl = request.getLocale();
        ResourceBundle rb = ResourceBundle.getBundle("paynowid",objLcl);
        String termUrl = rb.getString("termUrl");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = request.getParameter("orderId");
        // 金額
        String amount = request.getParameter("amount");
        // 与信方法
        String withCapture = request.getParameter("withCapture");
        // カードID
        String cardId = request.getParameter("cardId");
        // 支払方法
        String jpo1 = request.getParameter("jpo1");
        // 支払い回数
        String jpo2 = request.getParameter("jpo2");
        // セキュリティコード
        String securityCode = request.getParameter("secureCd");
        // カード番号
        String cardNumber = request.getParameter("cardNumber");
        // 有効期限
        String cardExpire = request.getParameter("cardExpire");
        // 決済種別
        String paymentMode = request.getParameter("paymentMode");
        // HTTP-Acceptの取得
        String httpAccept = request.getHeader("Accept");
        // HTTP-USERAGENTの取得
        String userAgent = request.getHeader("User-Agent");
        // 会員ID
        String accountId = request.getParameter("accountId");
        
        HttpSession session = request.getSession(true);
        session.setAttribute("paymentMode", paymentMode);
        // 与信である事を示すフラグをセッションに格納
        session.setAttribute("reAuthorizeFlg", "2");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        } else if (isNull(amount)) {
            warning =  "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, "./MpiAuthorizeExec.jsp");
            return;
        }

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        MpiAuthorizeRequestDto reqDto = new MpiAuthorizeRequestDto();

        // オーダーIDの設定
        reqDto.setOrderId(orderId);
        // 金額の設定
        reqDto.setAmount(amount);
        // カード番号
        reqDto.setCardNumber(cardNumber);
        // 有効期限
        reqDto.setCardExpire(cardExpire);
        // 決済種別
        // サービスオプションタイプの設定（固定値）
        if ("1".equals(paymentMode)) {
            reqDto.setServiceOptionType("mpi-none");
        } else if (paymentMode.equals("2")) {
            reqDto.setServiceOptionType("mpi-complete");
        } else if (paymentMode.equals("3")) {
            reqDto.setServiceOptionType("mpi-company");
        } else if (paymentMode.equals("4")) {
            reqDto.setServiceOptionType("mpi-merchant");
        } else {}

        // ペイメントオプション(支払方法・回数)の設定
        String jpo = null;
        if ("10".equals(jpo1) || "80".equals(jpo1)) {
            jpo = jpo1;
        } else if ("61".equals(jpo1) && jpo2 != null) {
            jpo = jpo1 + "C" + jpo2;
        }
        if (jpo != null) reqDto.setJpo(jpo);
        // セキュリティコード設定
        if (securityCode != null) reqDto.setSecurityCode(securityCode);
        // 与信方法によって、売上フラグを設定
        if ("1".equals(withCapture)) reqDto.setWithCapture("true");

        // Acceptの設定
        reqDto.setHttpAccept(httpAccept);
        // UserAgentの設定
        reqDto.setHttpUserAgent(userAgent);
        // RedirectionURLの設定    
        reqDto.setRedirectionUri(termUrl);

        //会員ID
        reqDto.setAccountId(accountId);
        //カードID
        reqDto.setCardId(cardId);

        /* ******************************************* */
        /* 標準カードフラグを設定する場合に設定(未設定時は1)   */
        /* ******************************************* */
        //reqDto.setDefaultCard("1");

        PrintWriter out = null;
        try {
            out = response.getWriter();

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction tran = TransactionFactory.getInstance(reqDto);
            MpiAuthorizeResponseDto resDto = (MpiAuthorizeResponseDto) tran.execute();

            // ログ
            System.out.println("PaymentMode["+paymentMode+"] : vResultCode="+resDto.getVResultCode());

            if ("success".equals(resDto.getMstatus())) {
                // 成功：ACS誘導HTMLを出力し、消費者ブラウザをACS認証画面へ誘導します
                String responseHtml = resDto.getResResponseContents();
                out.println(responseHtml);
                return;
            } else {
                if (resDto.getPayNowIdResponse() != null) {
                    request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());                
                }
                request.setAttribute("orderId", resDto.getOrderId());
                request.setAttribute("mStatus", resDto.getMstatus());
                request.setAttribute("vResultCode", resDto.getVResultCode());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());

                // 結果画面を表示します
                forward(request, response, "./MpiAuthorizeExec.jsp");

            }

        } catch (Exception ex) {
            // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            ex.printStackTrace();
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./MpiAuthorizeExec.jsp");
        }

    }

}
