package jp.veritrans.tercerog.sample.web.paynowid;

import java.io.IOException;
import java.util.LinkedHashMap;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.CardInfo;
import jp.veritrans.tercerog.mdk.dto.RecurringCharge;
import jp.veritrans.tercerog.mdk.dto.RecurringDeleteRequestDto;
import jp.veritrans.tercerog.mdk.dto.RecurringDeleteResponseDto;
import jp.veritrans.tercerog.mdk.dto.RecurringGetRequestDto;
import jp.veritrans.tercerog.mdk.dto.RecurringGetResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * 継続課金停止(カード払い)処理クラス
 */
public class RecurringTerminateExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        HttpSession session = request.getSession(true);
        String warning = null;
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 処理モードの取得
        String execMode = request.getParameter("execMode");
        // 会員IDの取得
        String accountId = request.getParameter("accountId");
        // グループID
        String groupId = request.getParameter("groupId");
        session.setAttribute("groupIdSelect", groupId);
        // 課金終了日の取得
        String endDate = request.getParameter("endDate");
        // 課金自動終了フラグ
        String finalCharge = request.getParameter("finalCharge");

        if ("1".equals(execMode)) {

            // 継続課金情報取得　//

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (isNull(accountId) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
            }

            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./RecurringTerminate.jsp");
                return;
            }
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            RecurringGetRequestDto reqDto = new RecurringGetRequestDto();
            reqDto.setAccountId(accountId);

            try {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                RecurringGetResponseDto resDto = (RecurringGetResponseDto) tran.execute();

                // 処理結果を取得する
                String mStatus = resDto.getMstatus();

                if ("success".equals(mStatus)) {
                    // カード情報
                    CardInfo[] cardInfos = resDto.getPayNowIdResponse().getAccount().getCardInfo();
                    // 会員課金情報
                    RecurringCharge[] recurringCharges = resDto.getPayNowIdResponse().getAccount().getRecurringCharge();
                    // 会員課金情報分繰り返す
                    LinkedHashMap map = new LinkedHashMap();
                    for (int i=0; i < recurringCharges.length; i++) {
                        CardInfo tempCardInfo = getCardInfo(recurringCharges[i].getCardId(),cardInfos);
                        map.put(recurringCharges[i].getGroupId(),
                                tempCardInfo.getCardNumber() + "：" + tempCardInfo.getCardExpire());
                    }
                    session.setAttribute("groupIdList", map);
                    session.setAttribute("groupIdSelect", "");

                     // 結果画面を表示します
                    forward(request, response, "./RecurringTerminate.jsp");

                } else {
                    if (resDto.getPayNowIdResponse() != null) {
                        request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                        request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                    }
                    request.setAttribute("vResultCode", resDto.getVResultCode());
                    request.setAttribute("mErrMsg", resDto.getMerrMsg());
                    forward(request, response, "./RecurringTerminateExec.jsp");
                }

            } catch (Exception ex) {
                // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                System.out.println("Exception Occured !");
                System.out.println("Exception Message: " + ex.getMessage());
                ex.printStackTrace();
                request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                forward(request, response, "./RecurringTerminateExec.jsp");
            }

        } else if ("2".equals(execMode)){

            // カード削除処理  //

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (isNull(accountId) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
            }
            // 課金グループID
            if (isNull(groupId) == true) {
                warning =  "<font color='#ff0000'><b>必須項目：課金グループIDが指定されていません</b></font>";
            }
            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./RecurringTerminate.jsp");
                return;
            }
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            RecurringDeleteRequestDto reqDto = new RecurringDeleteRequestDto();
            // 会員ID
            reqDto.setAccountId(accountId);
            // 課金終了日設定
            reqDto.setEndDate(endDate);
            // 課金グループID
            reqDto.setGroupId(groupId);
            // 次回課金自動終了フラグ
            reqDto.setFinalCharge(finalCharge);

            try {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                ITransaction tran = TransactionFactory.getInstance(reqDto);
                RecurringDeleteResponseDto resDto = (RecurringDeleteResponseDto) tran.execute();
                
                if (resDto.getPayNowIdResponse() != null) {
                    request.setAttribute("payNowIdProcId", resDto.getPayNowIdResponse().getProcessId());
                    request.setAttribute("payNowIdStatus", resDto.getPayNowIdResponse().getStatus());
                }
                request.setAttribute("vResultCode", resDto.getVResultCode());
                request.setAttribute("mErrMsg", resDto.getMerrMsg());

                // 結果画面を表示します
                forward(request, response, "./RecurringTerminateExec.jsp");

            } catch (Exception ex) {
                // トランザクションオブジェクトの生成失敗など、Exceptionが発生した場合はエラー画面を表示します。
                System.out.println("Exception Occured !");
                System.out.println("Exception Message: " + ex.getMessage());
                ex.printStackTrace();
                request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
                forward(request, response, "./RecurringTerminateExec.jsp");
            }
        } else {
            warning =  "<font color='#ff0000'><b>不正な処理です</b></font>";
            // エラー時の処理
            if (isNull(warning) == false) {
                request.setAttribute("warning", warning);
                // 入力画面に戻る
                forward(request, response, "./RecurringTerminate.jsp");
                return;
            }
        }
    }

    /**
     * カード情報からカードIDに対応する情報を取得する
     */
    private CardInfo getCardInfo(String cardId, CardInfo[] cardInfos) {
        for (int i=0; i < cardInfos.length; i++) {
            if (cardId.equals(cardInfos[i].getCardId())) {
                return cardInfos[i];
            }
        }
        CardInfo cardInfo = new CardInfo();
        cardInfo.setCardNumber("");
        cardInfo.setCardExpire("");
        return cardInfo;
    }
}
