package jp.veritrans.tercerog.sample.web.saison.base;

import java.io.IOException;
import java.io.UnsupportedEncodingException;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.SaisonCancelRequestDto;
import jp.veritrans.tercerog.mdk.dto.SaisonCancelResponseDto;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * クレディセゾン決済 取消処理クラス。
 */
public abstract class AbstractCancelExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    abstract protected String getJsp();
    abstract protected String getJspResult();
    abstract protected void setCharacterEncoding(HttpServletRequest request) throws UnsupportedEncodingException;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        // 文字コードの指定
        setCharacterEncoding(request);

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = request.getParameter("orderId");
        // カード取消フラグ
        String cardCancelFlag = request.getParameter("cardCancelFlag");


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 入力をチェックします。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        String warning = null;
        if (isNull(orderId)){
            warning =  "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
        }

        // エラー時の処理
        if (isNull(warning) == false) {
            request.setAttribute("warning", warning);
            // 入力画面に戻る
            forward(request, response, getJsp());
            return;
        }


        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        SaisonCancelRequestDto reqDto = new SaisonCancelRequestDto();

        // オーダーIDの設定
        reqDto.setOrderId(orderId);
        // カード取消フラグの設定
        reqDto.setCardCancelFlag(cardCancelFlag);

        request.setAttribute("processName", "取消");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // コマンドを実行し、応答DTOを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        ITransaction tran = TransactionFactory.getInstance(reqDto);
        SaisonCancelResponseDto resDto = (SaisonCancelResponseDto) tran.execute();

        // 処理結果の格納
        request.setAttribute("orderId", resDto.getOrderId());
        request.setAttribute("mStatus", resDto.getMstatus());
        request.setAttribute("mErrMsg", resDto.getMerrMsg());
        request.setAttribute("vResultCode", resDto.getVResultCode());


        // カード処理結果の格納
        request.setAttribute("cardOrderId", resDto.getCardOrderId());
        request.setAttribute("cardMStatus", resDto.getCardMstatus());
        request.setAttribute("cardMErrMsg", resDto.getCardMerrMsg());
        request.setAttribute("cardVResultCode", resDto.getCardVResultCode());
        request.setAttribute("reqCardNumber", resDto.getReqCardNumber());
        request.setAttribute("resAuthCode", resDto.getResAuthCode());

        forward(request, response, getJspResult());
    }

    /**
     * 文字列が数値であることをチェック。
     * @param num 検査する文字列
     * @return 数値の場合はtrue
     */
    private boolean isNum(String num) {
        if (num == null || num.length() == 0) {
            return true;
        }
        try {
            Integer.parseInt(num);
        } catch (NumberFormatException e) {
            return false;
        }
        return true;
    }

}
