package jp.veritrans.tercerog.sample.web.search.carrier;

import java.io.IOException;
import java.util.Arrays;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import jp.veritrans.tercerog.mdk.ITransaction;
import jp.veritrans.tercerog.mdk.TransactionFactory;
import jp.veritrans.tercerog.mdk.dto.AlipaySearchParameter;
import jp.veritrans.tercerog.mdk.dto.BankSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CardSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CarrierSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CommonSearchParameter;
import jp.veritrans.tercerog.mdk.dto.CvsSearchParameter;
import jp.veritrans.tercerog.mdk.dto.EmSearchParameter;
import jp.veritrans.tercerog.mdk.dto.MpiSearchParameter;
import jp.veritrans.tercerog.mdk.dto.OrderInfo;
import jp.veritrans.tercerog.mdk.dto.OrderInfos;
import jp.veritrans.tercerog.mdk.dto.PaypalSearchParameter;
import jp.veritrans.tercerog.mdk.dto.SaisonSearchParameter;
import jp.veritrans.tercerog.mdk.dto.SearchParameters;
import jp.veritrans.tercerog.mdk.dto.SearchRange;
import jp.veritrans.tercerog.mdk.dto.SearchRequestDto;
import jp.veritrans.tercerog.mdk.dto.SearchResponseDto;
import jp.veritrans.tercerog.mdk.dto.UpopSearchParameter;
import jp.veritrans.tercerog.sample.web.MdkSampleBaseServlet;

/**
 * キャリア決済処理クラス。
 */
public class SearchExec extends MdkSampleBaseServlet {
    private static final long serialVersionUID = 1L;

    /**
     * @see MdkSampleBaseServlet#doProcess
     */
    protected void doProcess(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // パラメータを取得します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 取引ID
        String orderId = getParameter(request, "orderId");

        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // 要求DTOを生成し、値を設定します。
        // +++++++++++++++++++++++++++++++++++++++++++++++++++++
        // Commonパラメータクラスへのセット
        CommonSearchParameter common_param = new CommonSearchParameter();
        common_param.setOrderId(orderId);

        // Searchパラメータクラスへのセット
        SearchParameters search_param = new SearchParameters();
        search_param.setCommon(common_param);

        // 検索DTOへパラメータクラスをセット
        SearchRequestDto request_data = new SearchRequestDto();
        request_data.setNewerFlag("false"); // 商品に紐付く全ての取引のみ対象にするかを示す
        request_data.setContainDummyFlag("1"); // 検索対象にダミー決済のレコードを含めるかを示す
        request_data.setServiceTypeCd(new String[]{ "carrier" }); // 検索対象のサービスタイプを示す
        request_data.setSearchParameters(search_param); // 各機能の固有条件

        try {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            ITransaction transaction = TransactionFactory.getInstance(request_data);
            SearchResponseDto response_data = (SearchResponseDto)transaction.execute();

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 結果画面に表示します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 処理結果メッセージを設定（View機能へ引き渡す）
            String warning = response_data.getMerrMsg();
            request.setAttribute("warning", warning);

            // 配列データを設定（View機能へ引き渡す）
            OrderInfos order_infos = response_data.getOrderInfos();
            if (order_infos != null && order_infos.getOrderInfo().length > 0) {
                // orderIdで検索しているため1件のみ返却される
                OrderInfo[] order_info = order_infos.getOrderInfo();
                request.setAttribute("order_info", order_info[0]);
            }

            // 結果画面を表示
            forward(request, response, "./SearchExec.jsp");
        } catch (Exception ex) {
            ex.printStackTrace();
            // トランザクションオブジェクトの生成失敗など、
            // Exceptionが発生した場合はエラー画面を表示します。
            System.out.println("Exception Occured !");
            System.out.println("Exception Message: " + ex.getMessage());
            request.setAttribute("mErrMsg", "Exception Occured : " + ex.getMessage());
            forward(request, response, "./SearchExec.jsp");
            return;
        } finally {
        }
    }

    /**
     * HTTPパラメータを取得する。
     * ただし、空文字の場合はnullへ変換される。
     */
    private String getParameter(final HttpServletRequest request, final String key) {
        String value = request.getParameter(key);
        if ("".equals(value)) {
            return null;
        } else {
            return value;
        }
    }

    /**
     * 検索対象の決済サービスタイプであるかをチェックする。
     */
    private boolean checkService(final String[] serviceTypeCd, final String target) {
        if (serviceTypeCd == null) {
            return false;
        }
        return Arrays.asList(serviceTypeCd).contains(target);
    }
}
